package com.yunzhi.shigongli.common;

import com.yunzhi.shigongli.vo.AMapWeather;
import net.coobird.thumbnailator.Thumbnails;
import net.coobird.thumbnailator.filters.Caption;
import net.coobird.thumbnailator.geometry.Coordinate;
import net.coobird.thumbnailator.geometry.Positions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.io.PipedInputStream;
import java.io.PipedOutputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.time.LocalDateTime;

@Component
public class ImageUtils {

    @Autowired
    OSSUtils ossUtils;

    public String renderWeatherPic(AMapWeather.Live weather, String backImageUrl) throws IOException {
        LocalDateTime now = LocalDateTime.now();
        String area = weather.getAdcode();
        String nmDate = DateUtils.toString(LocalDateTime.now(), "yyyyMMddHHmm");
        String fname = String.format("weather-%s-%s.jpg", area, nmDate);

        // 颜色
        Color color = Color.white;

        // 字体
        String fontName = "Microsoft YaHei";

        // 城市
        Font font1 = new Font(fontName, Font.BOLD, 40);
        Caption city = new Caption(weather.getCity(), font1, color, new Coordinate(124, 272 + 20), 0); // + 20 为字体大小的一半

        // 天气现象
        Font font2 = new Font(fontName, Font.BOLD, 40);
        Caption wthName = new Caption(weather.getWeather(), font2, color, new Coordinate(378, 190 + 20), 0);

        // 温度
        Font font3 = new Font(fontName, Font.BOLD, 130);
        Caption temperature = new Caption(weather.getTemperature() + "℃", font3, color, new Coordinate(84, 118 + 50), 0);

        // 湿度
        Font font4 = new Font(fontName, Font.BOLD, 32);
        int y4 = 540 + 30;
        Caption humidity = new Caption(weather.getHumidity() + "%", font4, color, new Coordinate(338, y4), 0);

        // 风向
        String wind = weather.getWinddirection() + "风 " + weather.getWindpower() + "级";
        Caption winddirection = new Caption(wind, font4, color, new Coordinate(78, y4), 0);

        // 日期
        String dateStr = DateUtils.toString(now, "MM/dd");
        String week = DateUtils.weekDay(now);
        Caption date = new Caption(dateStr + " " + week, font4, color, new Coordinate(500, y4), 0);

        // 绘制图片
        PipedInputStream inputStream = new PipedInputStream();
        PipedOutputStream out = new PipedOutputStream(inputStream);

        new Thread(new Runnable() {
            public void run () {
                try {
                    Thumbnails.of(new URL(backImageUrl))
                            .crop(Positions.CENTER)
                            .size(760, 600)
                            .addFilter(city)
                            .addFilter(wthName)
                            .addFilter(temperature)
                            .addFilter(humidity)
                            .addFilter(winddirection)
                            .addFilter(date)
                            .outputQuality(0.92)
                            .imageType(BufferedImage.TYPE_INT_ARGB)     // 预防 PNG 变黑的 BUG
                            .toOutputStream(out);
                }
                catch (IOException e) {
                    e.printStackTrace();
                }
                finally {
                    try {
                        out.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        }).start();

        String image = ossUtils.putObject(inputStream, fname);
        inputStream.close();

        return image;
    }


}
