package com.yunzhi.shigongli.common;

import com.yunzhi.shigongli.vo.AMapWeather;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

@Slf4j
@Component
public class Weather {

    @Value("${amap.weather.api}")
    String api;

    public AMapWeather getWeather(String areaId) throws Exception {
        RestTemplate restTemplate = new RestTemplate();

        String url = String.format(api, areaId);

        log.debug("请求高德天气接口: {}", url);

        ResponseEntity<AMapWeather> response = restTemplate.exchange(url, HttpMethod.GET, null, AMapWeather.class);
        if (null == response) {
            throw new Exception("请求天气接口异常");
        }

        HttpStatus statusCode = response.getStatusCode();
        boolean isSuccessful = statusCode.is2xxSuccessful();
        if (!isSuccessful) {
            log.error("请求天气接口[{}]出错, [{}]", url, statusCode.toString());
            throw new Exception("请求天气接口失败: " + statusCode.getReasonPhrase());
        }

        AMapWeather result = response.getBody();

        log.debug("高德天气接口返回: {}", result.toString());

        if (!"1".equals(result.getStatus())) {
            log.error("高德天气接口错误: {}", result.toString());
            throw new Exception("请求天气接口错误: " + result.getInfocode());
        }

        return result;
    }
}
