package com.yunzhi.shigongli.common;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.api.impl.WxMaServiceImpl;
import cn.binarywang.wx.miniapp.bean.WxMaCodeLineColor;
import cn.binarywang.wx.miniapp.config.impl.WxMaDefaultConfigImpl;
import com.github.binarywang.wxpay.config.WxPayConfig;
import com.github.binarywang.wxpay.constant.WxPayConstants;
import com.github.binarywang.wxpay.service.WxPayService;
import com.github.binarywang.wxpay.service.impl.WxPayServiceImpl;
import com.yunzhi.shigongli.config.WeixinConfig;
import lombok.Data;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class WxUtils {
    private static WxMaService service;
    private static WxPayService payService;

    @Autowired
    public WxUtils(WeixinConfig config) {
        setService(config);
        setPay(config);
    }

    private void setService(WeixinConfig config) {
        WxMaDefaultConfigImpl conf = new WxMaDefaultConfigImpl();
        conf.setAppid(config.getMiniapp().getAppid());
        conf.setSecret(config.getMiniapp().getSecret());
        conf.setToken(config.getMiniapp().getToken());
        conf.setAesKey(config.getMiniapp().getAesKey());
        conf.setMsgDataFormat(config.getMiniapp().getMsgDataFormat());

        service = new WxMaServiceImpl();
        service.setWxMaConfig(conf);
    }

    private void setPay(WeixinConfig config) {
        WxPayConfig payConfig = new WxPayConfig();
        payConfig.setAppId(config.getPay().getAppId());
        payConfig.setMchId(config.getPay().getMchId());
        payConfig.setMchKey(config.getPay().getMchKey());
        payConfig.setSubAppId(config.getPay().getSubAppId());
        payConfig.setSubMchId(config.getPay().getSubMchId());
        payConfig.setKeyPath(config.getPay().getKeyPath());
        // 固定小程序支付
        payConfig.setTradeType(WxPayConstants.TradeType.JSAPI);
        // 可以指定是否使用沙箱环境
        payConfig.setUseSandboxEnv(false);

        payService = new WxPayServiceImpl();
        payService.setConfig(payConfig);
    }

    public WxMaService getService() {
        return service;
    }
    public WxPayService getPayService() {
        return payService;
    }

    @Data
    public static class AQrCodeParam {
        private String scene;
        private String page;
        private int width;
        private boolean autoColor;
        private WxMaCodeLineColor lineColor;
        private boolean isHyaline;
    }
}
