package com.yunzhi.shigongli.controller;

import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.OSSUtils;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.config.AliyunConfig;
import com.yunzhi.shigongli.service.ITaOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Map;

@Api(tags = "通用")
@RestController
@RequestMapping("/")
public class CommController extends BaseController {

    @Autowired
    OSSUtils ossUtils;

    @Autowired
    AliyunConfig aliyunConfig;


    @Autowired
    ITaOrderService taOrderService;


    /**
     * 图片
     * @param multipartFile
     * @return
     */
    @ApiOperation(value = "图片上传", notes = "图片上传")
    @PostMapping("/{plat}/image")
    public ResponseBean uploadImage(@RequestParam("file") MultipartFile multipartFile) {
        try {
            String img = ossUtils.putObject(multipartFile);
            return ResponseBean.success(img);
        } catch (IOException e) {
            return ResponseBean.error("上传图片失败: " + e.getMessage(), ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 获取文件上传凭证
     * @return
     */
    @ApiOperation(value = "获取文件上传凭证", notes = "获取文件上传凭证")
    @GetMapping("/{plat}/oss-sts")
    public ResponseBean getOSSSTS() {
        AliyunConfig.Oss oss = aliyunConfig.getOss();

        try {
            Map<String, Object> res = ossUtils.getSTSAKToken();
            res.put("endpoint", oss.getEndpoint());
            res.put("bucket", oss.getBucketName());
            res.put("bucketURL", oss.getBucketURL());
            res.put("region", oss.getRegion());
            res.put("path", getMonth());

            return ResponseBean.success(res);
        } catch (Exception e) {
            return ResponseBean.error("获取上传凭证失败! ", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    private String getMonth() {
        return DateTimeFormatter.ofPattern("yyyy-MM").format(LocalDateTime.now());
    }

}
