package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaExtendContentService;
import com.yunzhi.shigongli.entity.TaExtendContent;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 扩展内容 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "扩展内容")
@RestController
@RequestMapping("/")
public class TaExtendContentController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaExtendContentController.class);

    @Autowired
    public ITaExtendContentService iTaExtendContentService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/taExtendContent",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taExtendContentList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                            @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                            @ApiParam("对象类型") @RequestParam(value ="targetType") String targetType,
                                            @ApiParam("对象ID") @RequestParam(value ="targetId") String targetId,
                                            HttpServletRequest request) throws Exception{

        IPage<TaExtendContent> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaExtendContent> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("target_type", targetType);
        queryWrapper.eq("target_id", targetId);
        queryWrapper.orderByAsc("sort");

        IPage<TaExtendContent> result = iTaExtendContentService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taExtendContent 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taExtendContent",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taExtendContentAdd(@ApiParam("保存内容") @RequestBody TaExtendContent taExtendContent) throws Exception{

        int max = iTaExtendContentService.getMaxSort(taExtendContent);
        taExtendContent.setSort(max + 1);

        if (iTaExtendContentService.save(taExtendContent)){
            return ResponseBean.success(taExtendContent);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taExtendContent/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taExtendContentDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaExtendContentService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taExtendContent 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taExtendContent/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taExtendContentUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaExtendContent taExtendContent) throws Exception{

        if (iTaExtendContentService.updateById(taExtendContent)){
            return ResponseBean.success(iTaExtendContentService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taExtendContent/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taExtendContentGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaExtendContentService.getById(id));
    }


    /**
     * 查询更多详情
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/{targetType}/{targetId}/content",method= RequestMethod.GET)
    @ApiOperation(value="查询更多详情", notes = "查询更多详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxList(@ApiParam("对象类型") @PathVariable String targetType,
                                  @ApiParam("对象ID") @PathVariable String targetId,
                                  @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                  @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "3") Integer pageSize) throws Exception{
        IPage<TaExtendContent> page = new Page<>(pageNum, pageSize);

        IPage<TaExtendContent> result = iTaExtendContentService.getWxListBy(page, targetType, targetId);

        return ResponseBean.success(result);
    }
}
