package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaFeedbackService;
import com.yunzhi.shigongli.entity.TaFeedback;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;

/**
 * <p>
    * 意见反馈 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "意见反馈")
@RestController
@RequestMapping("/")
public class TaFeedbackController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaFeedbackController.class);

    @Autowired
    public ITaFeedbackService iTaFeedbackService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taFeedback",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taFeedbackList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @ApiParam("是否管理首页") @RequestParam(value = "isIndex", required = false) Boolean isIndex ) throws Exception{

        IPage<TaFeedback> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaFeedback> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("create_date");

        if (null != isIndex && isIndex) {
            // 只查询近3天的, 且未读的数据
            LocalDateTime dt = LocalDateTime.now().minusDays(3);
            queryWrapper.ge("create_date", dt);
            queryWrapper.eq("is_readed", 0);
        }

        IPage<TaFeedback> result = iTaFeedbackService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taFeedback 实体对象
     * @return
     */
    @RequestMapping(value="/wx/taFeedback",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taFeedbackAdd(@ApiParam("保存内容") @RequestBody TaFeedback taFeedback) throws Exception{
        taFeedback.setIsReaded(false);
        if (iTaFeedbackService.save(taFeedback)){
            return ResponseBean.success(taFeedback);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taFeedback/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taFeedbackDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaFeedbackService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taFeedback 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taFeedback/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taFeedbackUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaFeedback taFeedback) throws Exception{
//
//        if (iTaFeedbackService.updateById(taFeedback)){
//            return ResponseBean.success(iTaFeedbackService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taFeedback/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taFeedbackGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        TaFeedback feedback = iTaFeedbackService.getById(id);

        // 更新为已读
        if (null == feedback.getIsReaded() || !feedback.getIsReaded()) {
            feedback.setIsReaded(true);
            feedback.setReadDate(LocalDateTime.now());
            iTaFeedbackService.updateById(feedback);
        }

        return ResponseBean.success(feedback);
    }
}
