package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaHotelAccountLogService;
import com.yunzhi.shigongli.entity.TaHotelAccountLog;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 民宿账户流水 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "民宿账户流水")
@RestController
@RequestMapping("/")
public class TaHotelAccountLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHotelAccountLogController.class);

    @Autowired
    public ITaHotelAccountLogService iTaHotelAccountLogService;


    /**
     * 获取账户流水
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/hotel/account/{id}/log",method= RequestMethod.GET)
    @ApiOperation(value="获取账户流水", notes = "获取账户流水", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHotelAccountLogList(@ApiParam("账户ID") @PathVariable String id,
                                              @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                              @ApiParam("账户流水类型") @RequestParam(value ="amountType", required = false) String amountType) throws Exception{

        if (StringUtils.isEmpty(amountType)) {
            amountType = Constants.ACCOUNT_COMMISSION;
        }

        IPage<TaHotelAccountLog> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaHotelAccountLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("account_id", id);
        queryWrapper.eq("amount_type", amountType);
        queryWrapper.orderByDesc("create_date");

        IPage<TaHotelAccountLog> result = iTaHotelAccountLogService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

//    /**
//     * 保存对象
//     * @param taHotelAccountLog 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taHotelAccountLog",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taHotelAccountLogAdd(@ApiParam("保存内容") @RequestBody TaHotelAccountLog taHotelAccountLog) throws Exception{
//
//        if (iTaHotelAccountLogService.save(taHotelAccountLog)){
//            return ResponseBean.success(taHotelAccountLog);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taHotelAccountLog/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taHotelAccountLogDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaHotelAccountLogService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taHotelAccountLog 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taHotelAccountLog/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taHotelAccountLogUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaHotelAccountLog taHotelAccountLog) throws Exception{
//
//        if (iTaHotelAccountLogService.updateById(taHotelAccountLog)){
//            return ResponseBean.success(iTaHotelAccountLogService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taHotelAccountLog/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taHotelAccountLogGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaHotelAccountLogService.getById(id));
//    }
}
