package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaHotelAccount;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.service.ITaHotelAccountService;
import com.yunzhi.shigongli.vo.HotelListVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaHotelService;
import com.yunzhi.shigongli.entity.TaHotel;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * <p>
    * 民宿 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "民宿")
@RestController
@RequestMapping("/")
public class TaHotelController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHotelController.class);

    @Autowired
    public ITaHotelService iTaHotelService;

    @Autowired
    public ITaHotelAccountService iTaHotelAccountService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/taHotel",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = HotelListVO.class)
    public ResponseBean taHotelList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                    @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                    @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                    @ApiParam("名称") @RequestParam(value = "hotelName",required = false) String hotelName) throws Exception{


        IPage<TaHotel> pg = new Page<>(pageNum, pageSize);
        IPage<HotelListVO> result = iTaHotelService.getVOListBy(pg, hotelName);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taHotel 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taHotel",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taHotelAdd(@ApiParam("保存内容") @RequestBody TaHotel taHotel) throws Exception{

        if (iTaHotelService.createNew(taHotel)){
            return ResponseBean.success(taHotel);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taHotel/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taHotelDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaHotelService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHotel 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taHotel/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taHotelUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaHotel taHotel) throws Exception{

//        boolean exists = iTaHotelService.isExisted(TaHotel::getHotelName,
//                taHotel.getHotelName(),
//                TaHotel::getHotelId,
//                taHotel.getHotelId());
//        if (exists) {
//            return ResponseBean.error("民宿名称已存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
//        }

        if (iTaHotelService.updateById(taHotel)){
            return ResponseBean.success(iTaHotelService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taHotel/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHotelGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaHotelService.getById(id));
    }


    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/hotel/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxDetail(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaHotelService.getById(id));
    }

    /**
     * 民宿小程序首页
     */
    @RequestMapping(value="/wx/hotel/manage/index",method= RequestMethod.GET)
    @ApiOperation(value="民宿小程序首页", notes = "民宿小程序首页", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxManageIndex() throws Exception{
        TaPerson taPerson = getCurrentPerson();
        if (!Constants.TARGET_HOTEL.equals(taPerson.getPersonRole())) {
            return ResponseBean.error("请先进行人员身份绑定", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 获取所有的民宿信息
        List<TaHotel> hotelList = iTaHotelService.getListByPerson(taPerson);
        if (null == hotelList || hotelList.size() < 1) {
            return ResponseBean.error("数据异常, 未找到关联民宿", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 默认获取第一个店铺信息
        TaHotel taHotel = hotelList.get(0);
        TaHotelAccount taHotelAccount = iTaHotelAccountService.getAccountInfoBy(taHotel.getHotelId());

        Map<String, Object> result = new HashMap<>();
        result.put("hotelList", hotelList);
        result.put("hotel", taHotel);
        result.put("account", taHotelAccount);

        return ResponseBean.success(result);
    }

    /**
     * 民宿小程序首页
     */
    @RequestMapping(value="/wx/hotel/manage/{id}",method= RequestMethod.GET)
    @ApiOperation(value="民宿小程序首页", notes = "民宿小程序首页", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxManageHotel(@ApiParam("民宿ID") @PathVariable String id) throws Exception{
        TaPerson taPerson = getCurrentPerson();
        if (!Constants.TARGET_HOTEL.equals(taPerson.getPersonRole())) {
            return ResponseBean.error("请先进行人员身份绑定", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 获取所有的民宿信息
        List<TaHotel> hotelList = iTaHotelService.getListByPerson(taPerson);
        if (null == hotelList || hotelList.size() < 1) {
            return ResponseBean.error("数据异常, 未找到关联民宿", ResponseBean.ERROR_UNAVAILABLE);
        }

        Optional<TaHotel> first = hotelList.stream().filter(x -> x.getHotelId().equals(id)).findFirst();
        if (!first.isPresent()) {
            return ResponseBean.error("数据异常, 未找到关联民宿", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 默认获取第一个店铺信息
        TaHotel taHotel = first.get();
        TaHotelAccount taHotelAccount = iTaHotelAccountService.getAccountInfoBy(taHotel.getHotelId());

        Map<String, Object> result = new HashMap<>();
        result.put("hotel", taHotel);
        result.put("account", taHotelAccount);

        return ResponseBean.success(result);
    }

}
