package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaNotification;
import com.yunzhi.shigongli.service.ITaNotificationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 通知公告 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "通知公告")
@RestController
@RequestMapping("/")
public class TaNotificationController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNotificationController.class);

    @Autowired
    public ITaNotificationService iTaNotificationService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/notification",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPvList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                 @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                 @ApiParam(value = "发布状态") @RequestParam(value ="status", required = false) Integer status) throws Exception{

        IPage<TaNotification> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaNotification> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("wx".equals(plat), "status", Constants.STATUS_NORMAL);
        queryWrapper.eq(null != status && "admin".equals(plat), "status", status);
        queryWrapper.gt(null == status && "admin".equals(plat), "status", Constants.STATUS_DELETED);
        queryWrapper.orderByDesc("weight");
        queryWrapper.orderByDesc("create_date");

        IPage<TaNotification> result = iTaNotificationService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taNotification 实体对象
     * @return
     */
    @RequestMapping(value="/admin/notification",method= RequestMethod.POST)
    @ApiOperation(value="新增通知公告", notes = "新增通知公告", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPvAdd(@ApiParam("保存内容") @RequestBody TaNotification taNotification) throws Exception{

        if (null == taNotification || StringUtils.isEmpty(taNotification.getContent())) {
            return ResponseBean.error("通知内容不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taNotification.setStatus(Constants.STATUS_READY);

        if (iTaNotificationService.save(taNotification)){
            return ResponseBean.success(taNotification);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/notification/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPvDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaNotificationService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNotification 实体对象
     * @return
     */
    @RequestMapping(value="/admin/notification/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPvUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaNotification taNotification) throws Exception {
        if (null == taNotification || StringUtils.isEmpty(taNotification.getContent())) {
            return ResponseBean.error("通知内容不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 只允许修改内容
        TaNotification notification = iTaNotificationService.getById(id);
        notification.setContent(taNotification.getContent());

        if (iTaNotificationService.updateById(notification)){
            return ResponseBean.success(notification);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 发布通知公告
     * @param id  实体ID
     * @return
     */
    @RequestMapping(value="/admin/notification/{id}/publish",method= RequestMethod.PUT)
    @ApiOperation(value="发布通知公告", notes = "发布通知公告", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean publish(@ApiParam("对象ID") @PathVariable String id) throws Exception {

        TaNotification notification = iTaNotificationService.getById(id);
        notification.setStatus(Constants.STATUS_NORMAL);

        if (iTaNotificationService.updateById(notification)){
            return ResponseBean.success(notification);
        }else {
            return ResponseBean.error("发布失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 取消发布通知公告
     * @param id  实体ID
     * @return
     */
    @RequestMapping(value="/admin/notification/{id}/unPublish",method= RequestMethod.PUT)
    @ApiOperation(value="取消发布通知公告", notes = "取消发布通知公告", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean unPublish(@ApiParam("对象ID") @PathVariable String id) throws Exception {

        TaNotification notification = iTaNotificationService.getById(id);
        notification.setStatus(Constants.STATUS_READY);

        if (iTaNotificationService.updateById(notification)){
            return ResponseBean.success(notification);
        }else {
            return ResponseBean.error("取消发布失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    /**
     * 获取详情
     * @param id  实体ID
     * @return
     */
    @RequestMapping(value="/admin/notification/{id}",method= RequestMethod.GET)
    @ApiOperation(value="获取详情", notes = "获取详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getDetail(@ApiParam("对象ID") @PathVariable String id) throws Exception {

        TaNotification notification = iTaNotificationService.getById(id);
        if (Constants.STATUS_DELETED.equals(notification.getStatus())) {
            return ResponseBean.error("未找到相关内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return ResponseBean.success(notification);
    }
}
