package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.binarywang.wxpay.bean.order.WxPayMpOrderResult;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaOrderSub;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.service.ITaOrderPayService;
import com.yunzhi.shigongli.service.ITaOrderSubService;
import com.yunzhi.shigongli.service.ITaVerifyTargetService;
import com.yunzhi.shigongli.vo.OrderItem;
import com.yunzhi.shigongli.vo.RefundParamsVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaOrderService;
import com.yunzhi.shigongli.entity.TaOrder;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    * 订单表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "订单表")
@RestController
@RequestMapping("/")
public class TaOrderController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrderController.class);

    @Autowired
    public ITaOrderService iTaOrderService;

    @Autowired
    public ITaOrderSubService iTaOrderSubService;

    @Autowired
    public ITaOrderPayService iTaOrderPayService;

    @Autowired
    public ITaVerifyTargetService iTaVerifyTargetService;

//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taOrder",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taOrderList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaOrder> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaOrder> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaOrder> result = iTaOrderService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }

    /**
     * 小程序下单
     * @param orderItems
     * @param request
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/wx/order",method= RequestMethod.POST)
    @ApiOperation(value="生成订单", notes = "生成订单", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taOrderAdd(@ApiParam("订单内容") @RequestBody OrderItem[] orderItems,
                                   HttpServletRequest request) throws Exception{
        if (null == orderItems|| orderItems.length < 1) {
            return ResponseBean.error("未找到订单内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson person = getCurrentPerson();
        TaOrder taOrder = iTaOrderService.order(person, orderItems);
        WxPayMpOrderResult result = iTaOrderPayService.prePay(person, taOrder);
        return ResponseBean.success(result);
    }

    /**
     * 小程序发起支付
     * @param id
     * @param request
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/wx/order/{id}/pay",method= RequestMethod.POST)
    @ApiOperation(value="发起支付", notes = "发起支付", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taOrderPay(@ApiParam("订单号") @PathVariable String id,
                                   HttpServletRequest request) throws Exception{
        TaOrder taOrder = iTaOrderService.getById(id);
        if (null == taOrder || Constants.STATUS_DELETED.equals(taOrder.getStatus())) {
            return ResponseBean.error("未找到订单信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!Constants.ORDER_READY.equals(taOrder.getStatus())) {
            return ResponseBean.error("订单非未支付状态, 不能完成操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson person = getCurrentPerson();
        WxPayMpOrderResult result = iTaOrderPayService.prePay(person, taOrder);
        return ResponseBean.success(result);
    }

    /**
     * 取消订单
     * @param id
     * @param request
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/wx/order/{id}",method= RequestMethod.DELETE)
    @ApiOperation(value="取消订单", notes = "取消订单", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taOrderDelete(@ApiParam("订单ID") @PathVariable String id,
                                   HttpServletRequest request) throws Exception{
        TaOrder taOrder = iTaOrderService.getById(id);
        if (null == taOrder || Constants.STATUS_DELETED.equals(taOrder.getStatus())) {
            return ResponseBean.error("订单不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();
        if (!taPerson.getPersonId().equals(taOrder.getPersonId())) {
            return ResponseBean.error("您无权取消当前订单", ResponseBean.ERROR_UNAVAILABLE);
        }

        iTaOrderService.cancelOrder(taOrder, taPerson);
        return ResponseBean.success("取消成功");
    }

    /**
     * 订单退款
     * @param id
     * @param request
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/wx/order/{id}/refund",method= RequestMethod.DELETE)
    @ApiOperation(value="订单退款", notes = "订单退款", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taOrderPayCancel(@ApiParam("订单号") @PathVariable String id,
                                   @ApiParam("退款说明") @RequestBody RefundParamsVO refundParamsVO,
                                   HttpServletRequest request) throws Exception{
        TaOrder taOrder = iTaOrderService.getById(id);
        if (null == taOrder || Constants.STATUS_DELETED.equals(taOrder.getStatus())) {
            return ResponseBean.error("未找到订单信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null == refundParamsVO
                || (StringUtils.isEmpty(refundParamsVO.getRefundReason())
                && StringUtils.isEmpty(refundParamsVO.getRefundDecription()))) {
            return ResponseBean.error("请设置退款原因", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taOrder.setRefundReason(refundParamsVO.getRefundReason());
        taOrder.setRefundDecription(refundParamsVO.getRefundDecription());

        if (!Constants.ORDER_PAYED.equals(taOrder.getStatus())) {
            return ResponseBean.error("订单非未支付状态, 不能完成操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();
        if (!taPerson.getPersonId().equals(taOrder.getPersonId())) {
            return ResponseBean.error("您无权取消当前订单", ResponseBean.ERROR_UNAVAILABLE);
        }

        List<TaOrderSub> orderSubList = iTaOrderSubService.getListByOrder(taOrder);
        if (null == orderSubList || orderSubList.size() < 1) {
            throw new Exception("未找到订单详情");
        }

        // 只有全部为已支付的可以取消
        Object[] o1 = orderSubList.stream().filter(x -> !Constants.ORDER_PAYED.equals(x.getStatus()) || x.getIsVerified()).toArray();
        if (o1.length > 0) {
            throw new Exception("订单存在非支付状态项目, 不能退款");
        }

        // 如果存在已核销的, 则不能退款
        int cnt = iTaVerifyTargetService.getCountBy(taOrder.getOrderId(), null, 1);
        if (cnt > 0) {
            return ResponseBean.error("当前存在已核销内容, 不能退款", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 计算返现总额
        Integer totalCashback = orderSubList.stream().mapToInt(TaOrderSub::getCashback).reduce(Integer::sum).getAsInt();

        TaPerson person = getCurrentPerson();
        iTaOrderService.refundOrder(taOrder, taPerson, totalCashback);

        return ResponseBean.success("success");
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taOrder/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taOrderDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaOrderService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taOrder 实体对象
//     * @return
//     */
//    @RequestMapping(value="/wx/taOrder/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taOrderUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaOrder taOrder) throws Exception{
//
//        if (iTaOrderService.updateById(taOrder)){
//            return ResponseBean.success(iTaOrderService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/{plat}/taOrder/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taOrderGet(@ApiParam("客户端") @PathVariable String plat,
//                                   @ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaOrderService.getById(id));
//    }
}
