package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaHotelWorker;
import com.yunzhi.shigongli.entity.TaPersonRole;
import com.yunzhi.shigongli.entity.TaShopWorker;
import com.yunzhi.shigongli.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.entity.TaPerson;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 小程序人员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "小程序人员表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;

    @Autowired
    public ITaPersonRoleService iTaPersonRoleService;

    @Autowired
    public ITaShopWorkerService iTaShopWorkerService;

    @Autowired
    public ITaHotelWorkerService iTaHotelWorkerService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taPerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }


    /**
     * 绑定人员身份
     * @param targetType
     * @return
     */
    @RequestMapping(value="/wx/person-role/{targetType}",method= RequestMethod.POST)
    @ApiOperation(value="绑定人员身份", notes = "绑定人员身份", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean savePersonRole(@ApiParam("身份类型") @PathVariable String targetType) throws Exception{
        TaPerson taPerson = getCurrentPerson();
        if (StringUtils.isEmpty(taPerson.getPhone())) {
            return ResponseBean.error("请先授权手机号", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taPerson.setPersonRole(targetType);

        // 绑定普通用户身份不需要操作任何内容
        if ("normal".equals(targetType)) {
            iTaPersonService.updateById(taPerson);
            return ResponseBean.success(taPerson);
        }

        TaPersonRole taPersonRole = iTaPersonRoleService.getPersonRole(taPerson, targetType);
        if (null != taPersonRole) {
            if (Constants.STATUS_NORMAL.equals(taPersonRole.getStatus())) {
                iTaPersonService.updateById(taPerson);

                return ResponseBean.success(taPerson);
            } else {
                return ResponseBean.error("绑定数据异常, 请联系管理人员", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }
        }

        List<String> targetTypeList = new ArrayList<String>(){{
            add(Constants.TARGET_SHOP);
            add(Constants.TARGET_HOTEL);
        }};
        if (!targetTypeList.contains(targetType)) {
            return ResponseBean.error("暂不支持的身份类型", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taPersonRole = new TaPersonRole();
        taPersonRole.setPersonId(taPerson.getPersonId());
        taPersonRole.setTargetType(targetType);
        taPersonRole.setStatus(Constants.STATUS_NORMAL);

        // 如果是商铺
        if (Constants.TARGET_SHOP.equals(targetType)) {
            List<TaShopWorker> shopWorkers = iTaShopWorkerService.getByPhone(taPerson.getPhone());
            if (null == shopWorkers || shopWorkers.size() < 1) {
                return ResponseBean.error("未找到有效的身份对应信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }
            iTaShopWorkerService.updateByPerson(taPerson);
        }

        // 如果是商铺
        if (Constants.TARGET_HOTEL.equals(targetType)) {
            List<TaHotelWorker> shopWorkers = iTaHotelWorkerService.getByPhone(taPerson.getPhone());
            if (null == shopWorkers || shopWorkers.size() < 1) {
                return ResponseBean.error("未找到有效的身份对应信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }
            iTaHotelWorkerService.updateByPerson(taPerson);
        }

        iTaPersonRoleService.save(taPersonRole);
        iTaPersonService.updateById(taPerson);

        return ResponseBean.success(taPerson);
    }


//
//    /**
//     * 保存对象
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.save(taPerson)){
//            return ResponseBean.success(taPerson);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPersonService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taPersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{
//
//        if (iTaPersonService.updateById(taPerson)){
//            return ResponseBean.success(iTaPersonService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaPersonService.getById(id));
//    }
}
