package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.service.ITaResourceService;
import com.yunzhi.shigongli.vo.ResourceListVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资源表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "资源表")
@RestController
@RequestMapping("/")
public class TaResourceController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaResourceController.class);

    @Autowired
    public ITaResourceService iTaResourceService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/resource",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                @ApiParam("定位") @RequestParam(value ="location", required = false) String location,
                                @ApiParam("分类") @RequestParam(value ="typeId", required = false) String typeId,
                                @ApiParam("关键词") @RequestParam(value ="q", required = false) String q,
                                @ApiParam("资源类型") @RequestParam(value ="targetType", required = false) String targetType) throws Exception{

        IPage<ResourceListVO> pg = new Page<>(pageNum, pageSize);
        IPage<ResourceListVO> result = null;

        if (!StringUtils.isEmpty(q)) {
            // 如果使用的搜索, 则走搜索的方法
            result = iTaResourceService.searchList(pg, getCurrentPerson(), location, q, targetType);
        } else {
            result = iTaResourceService.getWxPagedBy(pg, getCurrentPerson(), location, typeId);
        }

        return ResponseBean.success(result);
    }


//    /**
//     * 保存对象
//     * @param taPv 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPv",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taPvAdd(@ApiParam("保存内容") @RequestBody TaPv taPv) throws Exception{
//
//        if (iTaPvService.save(taPv)){
//            return ResponseBean.success(taPv);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPv/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taPvDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaPvService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taPv 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taPv/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taPvUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaPv taPv) throws Exception{
//
//        if (iTaPvService.updateById(taPv)){
//            return ResponseBean.success(iTaPvService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taPv/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taPvGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaPvService.getById(id));
//    }
}
