package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaShopWorker;
import com.yunzhi.shigongli.vo.RoomListVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaRoomService;
import com.yunzhi.shigongli.entity.TaRoom;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 房源 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "房源")
@RestController
@RequestMapping("/")
public class TaRoomController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRoomController.class);

    @Autowired
    public ITaRoomService iTaRoomService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{plat}/taRoom",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRoomList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                   @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @ApiParam("民宿ID") @RequestParam(value ="hotelId", required = false) String hotelId,
                                   @ApiParam("民宿ID") @RequestParam(value ="roomName", required = false) String roomName) throws Exception{

        if ("wx".equals(plat) && StringUtils.isEmpty(hotelId)) {
            return ResponseBean.error("未找到有效的民宿ID", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        IPage<TaRoom> pg = new Page<>(pageNum, pageSize);
        IPage<RoomListVO> result = iTaRoomService.getPageListBy(pg, plat, hotelId, roomName);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taRoom 实体对象
     * @return
     */
    @RequestMapping(value="/{plat}/taRoom",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taRoomAdd(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                  @ApiParam("保存内容") @RequestBody TaRoom taRoom) throws Exception{

        if (iTaRoomService.save(taRoom)){
            return ResponseBean.success(taRoom);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{plat}//taRoom/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taRoomDelete(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                     @ApiParam("对象ID") @PathVariable String id) throws Exception{
        if ("wx".equals(plat)) {
            TaPerson taPerson = getCurrentPerson();

            // 校验当前人员是否有管理权限
            boolean isExistKeeper = iTaRoomService.getIsExistKeeper(id, taPerson.getPersonId());
            if (!isExistKeeper) {
                return ResponseBean.error("您无权进行此操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }
        }

        if(iTaRoomService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRoom 实体对象
     * @return
     */
    @RequestMapping(value="/{plat}/taRoom/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taRoomUpdate(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                     @ApiParam("对象ID") @PathVariable String id,
                                     @ApiParam("更新内容") @RequestBody TaRoom taRoom) throws Exception{

        if (iTaRoomService.updateById(taRoom)){
            return ResponseBean.success(iTaRoomService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{plat}/taRoom/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRoomGet(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String plat,
                                  @ApiParam("对象ID") @PathVariable String id) throws Exception{

        TaRoom taRoom = iTaRoomService.getById(id);
        if (null == taRoom || Constants.STATUS_DELETED.equals(taRoom.getStatus())) {
            return ResponseBean.error("未找到房源信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return ResponseBean.success(taRoom);
    }
}
