package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.*;
import com.yunzhi.shigongli.entity.TaHotel;
import com.yunzhi.shigongli.entity.TaRoom;
import com.yunzhi.shigongli.entity.TaRoomOrderPerson;
import com.yunzhi.shigongli.service.ITaHotelService;
import com.yunzhi.shigongli.service.ITaRoomOrderPersonService;
import com.yunzhi.shigongli.service.ITaRoomService;
import com.yunzhi.shigongli.vo.AMapWeather;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.shigongli.service.ITaRoomOrderService;
import com.yunzhi.shigongli.entity.TaRoomOrder;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 房源订单 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "房源订单")
@RestController
@RequestMapping("/")
public class TaRoomOrderController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRoomOrderController.class);

    @Autowired
    public ITaRoomOrderService iTaRoomOrderService;

    @Autowired
    public ITaRoomOrderPersonService roomOrderPersonService;

    @Autowired
    public ITaRoomService iTaRoomService;

    @Autowired
    public ITaHotelService iTaHotelService;

    @Autowired
    public Weather weatherUtil;

    @Autowired
    public ImageUtils imageUtils;

    @Value("${amap.weather.backImage}")
    private String backImage;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/roomOrder",method= RequestMethod.GET)
    @ApiOperation(value="房源订单列表", notes = "房源订单列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRoomOrderList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        @ApiParam("房源ID") @RequestParam("roomId") String roomId ) throws Exception{

        IPage<TaRoomOrder> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaRoomOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("room_id", roomId);
        queryWrapper.eq("status", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaRoomOrder> result = iTaRoomOrderService.page(pg, queryWrapper);

        // 遍历房源入住人
        List<TaRoomOrder> list = result.getRecords();
        if (null != list) {
            for (TaRoomOrder roomOrder : list) {
                List<TaRoomOrderPerson> personList = roomOrderPersonService.getListByRoomOrder(roomOrder.getRoomOrderId());
                roomOrder.setPersonList(personList);
            }
        }

        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taRoomOrder 实体对象
     * @return
     */
    @RequestMapping(value="/wx/roomOrder",method= RequestMethod.POST)
    @ApiOperation(value="房源订单/分享房源", notes = "房源订单/分享房源", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taRoomOrderAdd(@ApiParam("房源订单") @RequestBody TaRoomOrder taRoomOrder) throws Exception{

        String roomId = taRoomOrder.getRoomId();
        if (StringUtils.isEmpty(roomId)) {
            return ResponseBean.error("房源不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        TaRoom taRoom = iTaRoomService.getById(roomId);
        if (null == taRoom || !Constants.STATUS_NORMAL.equals(taRoom.getStatus())) {
            return ResponseBean.error("房源不存在或者状态异常", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
//        TaHotel taHotel = iTaHotelService.getById(taRoom.getHotelId());
//        if (null == taHotel || !Constants.STATUS_NORMAL.equals(taHotel.getStatus())) {
//            return ResponseBean.error("民宿不存在或者状态异常", ResponseBean.ERROR_ILLEGAL_PARAMS);
//        }

        // 地区暂时是南京市秦淮区
        AMapWeather weather = weatherUtil.getWeather("320104");
        AMapWeather.Live live = weather.getLives().get(0);
        String image = imageUtils.renderWeatherPic(live, String.format(backImage, "晴"));

        taRoomOrder.setHotelId(taRoom.getHotelId());
        taRoomOrder.setSharePerson(getCurrentPerson().getPersonId());
        taRoomOrder.setStatus(Constants.STATUS_READY);
        taRoomOrder.setCreateDate(LocalDateTime.now());

        if (iTaRoomOrderService.save(taRoomOrder)){
            taRoomOrder.setShareImage(image);
            return ResponseBean.success(taRoomOrder);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRoomOrder/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taRoomOrderDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaRoomOrderService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taRoomOrder 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taRoomOrder/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taRoomOrderUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaRoomOrder taRoomOrder) throws Exception{
//
//        if (iTaRoomOrderService.updateById(taRoomOrder)){
//            return ResponseBean.success(iTaRoomOrderService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/roomOrder/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taRoomOrderGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaRoomOrderService.getById(id));
    }

    @GetMapping("/test-weather")
    public ResponseBean testWeather() throws Exception {
        AMapWeather weather = weatherUtil.getWeather("320105");

        String image = imageUtils.renderWeatherPic(weather.getLives().get(0), "https://yz-shigongli.oss-cn-shanghai.aliyuncs.com/images/weather/background_%E6%99%B4.png");

        return ResponseBean.success(image);
    }
}
