package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaRoom;
import com.yunzhi.shigongli.entity.TaRoomOrder;
import com.yunzhi.shigongli.service.ITaRoomOrderService;
import com.yunzhi.shigongli.service.ITaRoomService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaRoomOrderPersonService;
import com.yunzhi.shigongli.entity.TaRoomOrderPerson;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 房源订单打开人 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "房源订单打开人")
@RestController
@RequestMapping("/")
public class TaRoomOrderPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRoomOrderPersonController.class);

    @Autowired
    public ITaRoomOrderPersonService iTaRoomOrderPersonService;

    @Autowired
    public ITaRoomOrderService iTaRoomOrderService;

    @Autowired
    public ITaRoomService iTaRoomService;


    /**
     * 保存对象
     * @param roomOrderPersonList 实体对象
     * @return
     */
    @RequestMapping(value="/wx/room-order/{id}/person",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taRoomOrderPersonAdd(@ApiParam("房源订单ID") @PathVariable String id,
                                             @ApiParam("保存内容") @RequestBody List<TaRoomOrderPerson> roomOrderPersonList) throws Exception{

        if (null == roomOrderPersonList || roomOrderPersonList.size() < 1) {
            return ResponseBean.error("没有找到提交的内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaRoomOrder taRoomOrder = iTaRoomOrderService.getById(id);
        if (taRoomOrder == null || Constants.STATUS_DELETED.equals(taRoomOrder.getStatus())) {
            return ResponseBean.error("未找到有效的房源信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaRoom taRoom = iTaRoomService.getById(taRoomOrder.getRoomId());
        if (taRoom == null || !Constants.STATUS_NORMAL.equals(taRoom.getStatus())) {
            return ResponseBean.error("未找到有效的房源信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();
        LocalDateTime now = LocalDateTime.now();

        for (TaRoomOrderPerson roomOrderPerson : roomOrderPersonList) {
            if (StringUtils.isEmpty(roomOrderPerson.getCustomerName()) || StringUtils.isEmpty(roomOrderPerson.getCustomerPhone())) {
                return ResponseBean.error("入住人信息不完整", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            roomOrderPerson.setRoomOrderId(id);
            roomOrderPerson.setPersonId(taPerson.getPersonId());
            roomOrderPerson.setCreateDate(now);
        }

        if (iTaRoomOrderPersonService.saveBatch(roomOrderPersonList)){
            taRoomOrder.setStatus(Constants.STATUS_NORMAL);
            iTaRoomOrderService.updateById(taRoomOrder);

            return ResponseBean.success(roomOrderPersonList);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRoomOrderPerson/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taRoomOrderPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaRoomOrderPersonService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taRoomOrderPerson 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taRoomOrderPerson/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taRoomOrderPersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaRoomOrderPerson taRoomOrderPerson) throws Exception{
//
//        if (iTaRoomOrderPersonService.updateById(taRoomOrderPerson)){
//            return ResponseBean.success(iTaRoomOrderPersonService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taRoomOrderPerson/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taRoomOrderPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaRoomOrderPersonService.getById(id));
//    }
}
