package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.entity.TaLike;
import com.yunzhi.shigongli.entity.TaSave;
import com.yunzhi.shigongli.service.ITaResourceService;
import com.yunzhi.shigongli.service.ITaSaveService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;

/**
 * <p>
    * 收藏表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "收藏表")
@RestController
@RequestMapping("/")
public class TaSaveController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaSaveController.class);

    @Autowired
    public ITaSaveService iTaSaveService;

    @Autowired
    public ITaResourceService iTaResourceService;

//
//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/admin/save",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taLikeList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaSave> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaSave> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaSave> result = iTaSaveService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }

    /**
     * 保存对象
     * @return
     */
    @RequestMapping(value="/wx/{targetType}/save/{targetId}",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taLikeAdd(@ApiParam("对象类型") @PathVariable String targetType,
                                  @ApiParam("对象ID") @PathVariable String targetId) throws Exception{
        TaSave taSave = new TaSave();
        taSave.setTargetType(targetType);
        taSave.setTargetId(targetId);
        taSave.setPersonId(getCurrentPerson().getPersonId());
        taSave.setCreateDate(LocalDateTime.now());

        if (iTaSaveService.save(taSave)){
            iTaResourceService.updateSave(taSave, 1);
            return ResponseBean.success(taSave);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     */
    @RequestMapping(value="/wx/{targetType}/save/{targetId}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taLikeDelete(@ApiParam("对象类型") @PathVariable String targetType,
                                     @ApiParam("对象ID") @PathVariable String targetId) throws Exception{
        TaSave taSave = iTaSaveService.getByTarget(targetType, targetId, getCurrentPerson().getPersonId());

        if(iTaSaveService.removeById(taSave.getSaveId())){
            iTaResourceService.updateSave(taSave, -1);
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taLike 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taLike/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taLikeUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaLike taLike) throws Exception{
//
//        if (iTaLikeService.updateById(taLike)){
//            return ResponseBean.success(iTaLikeService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 根据id查询对象
     * @param targetType  对象类型
     * @param targetId  对象ID
     */
    @RequestMapping(value="/wx/{targetType}/save/{targetId}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taLikeGet(@ApiParam("对象类型") @PathVariable String targetType,
                                  @ApiParam("对象ID") @PathVariable String targetId) throws Exception{
        TaSave taSave = iTaSaveService.getByTarget(targetType, targetId, getCurrentPerson().getPersonId());

        return ResponseBean.success(taSave);
    }
}
