package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.*;
import com.yunzhi.shigongli.entity.TaHotelAccount;
import com.yunzhi.shigongli.service.ITaOrderSubService;
import com.yunzhi.shigongli.service.ITaShopAccountLogService;
import com.yunzhi.shigongli.vo.CommissionSettlementVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.shigongli.service.ITaShopAccountService;
import com.yunzhi.shigongli.entity.TaShopAccount;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
    * 民宿账户 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "民宿账户")
@RestController
@RequestMapping("/")
public class TaShopAccountController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopAccountController.class);

    @Autowired
    public ITaShopAccountService iTaShopAccountService;

    @Autowired
    public ITaOrderSubService iTaOrderSubService;

    @Autowired
    public ITaShopAccountLogService iTaShopAccountLogService;

    /**
     * 佣金结算
     * @param commissionSettlementVO
     * @return
     * @throws Exception
     */
    @PutMapping("/admin/shopAccount/commission/settlement")
    @ApiOperation(value="佣金结算", notes = "佣金结算", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean commissionSettlement(@ApiParam("结算佣金") @RequestBody CommissionSettlementVO commissionSettlementVO) throws Exception {
        String shopId = commissionSettlementVO.getTargetId();
        if (StringUtils.isEmpty(shopId)) {
            return ResponseBean.error("未找到结算民宿对象", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (null == commissionSettlementVO.getCharges() || commissionSettlementVO.getCharges() < 1) {
            return ResponseBean.error("请设置有效的结算金额", ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaShopAccount taShopAccount = iTaShopAccountService.getByShop(shopId);
        if (null == taShopAccount) {
            return ResponseBean.error("未找到有效的结算民宿对象", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (taShopAccount.getBrokerageCharges() - taShopAccount.getPaidCharges() < commissionSettlementVO.getCharges()) {
            return ResponseBean.error("佣金不足", ResponseBean.ERROR_MISSING_PARAMS);
        }

        boolean success = iTaShopAccountService.commissionSettlement(taShopAccount, commissionSettlementVO.getCharges());
        if (success) {
            return ResponseBean.success("success");
        } else {
            return ResponseBean.error("结算失败请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @GetMapping("/wx/shop/{id}/account")
    @ApiOperation(value="商铺账户", notes = "商铺账户", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getAccountInfo(@ApiParam("对象ID") @PathVariable String id,
                                       @ApiParam("收入类型") @RequestParam("amountType") String amountType) throws Exception {

        Map<String, Object> result = new HashMap<>();
        TaShopAccount taShopAccount = iTaShopAccountService.getByShop(id);
        if (null == taShopAccount) {
            return ResponseBean.error("未找到有效的结算民宿对象", ResponseBean.ERROR_MISSING_PARAMS);
        }
        result.put("acc", taShopAccount);

        LocalDateTime now = LocalDateTime.now();
        if (Constants.ACCOUNT_ORDER.equals(amountType)) {
            // 获取全部订单金额
            LocalDateTime start = DateUtils.from("2000-01-01 00:00:00", "yyyy-MM-dd HH:mm:ss");
            LocalDateTime end = now;
            Integer totalCharges = iTaOrderSubService.getTotalCharges(Constants.TARGET_SHOP, id, start, end);
            result.put("totalCharges", totalCharges);
            // 本月订单金额
            String month = DateUtils.toString(end, "yyyy-MM");
            start = DateUtils.from(month + "-01 00:00:00", "yyyy-MM-dd HH:mm:ss");
            Integer currentCharges = iTaOrderSubService.getTotalCharges(Constants.TARGET_SHOP, id, start, end);
            result.put("currentCharges", currentCharges);
        }

        if (Constants.ACCOUNT_COMMISSION.equals(amountType)) {
            // 获取全部佣金金额
            LocalDateTime start = DateUtils.from("2000-01-01 00:00:00", "yyyy-MM-dd HH:mm:ss");
            LocalDateTime end = now;
            Integer totalCharges = iTaShopAccountLogService.getTotalCharges(taShopAccount.getAccountId(), Constants.ACCOUNT_COMMISSION, start, end);
            result.put("totalCharges", totalCharges);
            // 本月订单金额
            String month = DateUtils.toString(end, "yyyy-MM");
            start = DateUtils.from(month + "-01 00:00:00", "yyyy-MM-dd HH:mm:ss");
            Integer currentCharges = iTaShopAccountLogService.getTotalCharges(taShopAccount.getAccountId(), Constants.ACCOUNT_COMMISSION, start, end);
            result.put("currentCharges", currentCharges);
        }

        return ResponseBean.success(result);
    }

//
//
//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taShopAccount",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taShopAccountList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaShopAccount> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaShopAccount> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaShopAccount> result = iTaShopAccountService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }
//
//    /**
//     * 保存对象
//     * @param taShopAccount 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taShopAccount",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taShopAccountAdd(@ApiParam("保存内容") @RequestBody TaShopAccount taShopAccount) throws Exception{
//
//        if (iTaShopAccountService.save(taShopAccount)){
//            return ResponseBean.success(taShopAccount);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taShopAccount/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taShopAccountDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaShopAccountService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taShopAccount 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taShopAccount/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taShopAccountUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaShopAccount taShopAccount) throws Exception{
//
//        if (iTaShopAccountService.updateById(taShopAccount)){
//            return ResponseBean.success(iTaShopAccountService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taShopAccount/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taShopAccountGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaShopAccountService.getById(id));
//    }
}
