package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaHotelAccountLog;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaShopAccountLogService;
import com.yunzhi.shigongli.entity.TaShopAccountLog;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 商户账户流水 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "商户账户流水")
@RestController
@RequestMapping("/")
public class TaShopAccountLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopAccountLogController.class);

    @Autowired
    public ITaShopAccountLogService iTaShopAccountLogService;

    /**
     * 获取账户流水
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/shop/account/{id}/log",method= RequestMethod.GET)
    @ApiOperation(value="获取账户流水", notes = "获取账户流水", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHotelAccountLogList(@ApiParam("账户ID") @PathVariable String id,
                                              @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                              @ApiParam("账户流水类型") @RequestParam(value ="amountType", required = false) String amountType) throws Exception{

        if (StringUtils.isEmpty(amountType)) {
            amountType = Constants.ACCOUNT_COMMISSION;
        }

        IPage<TaShopAccountLog> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaShopAccountLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("account_id", id);
        queryWrapper.eq("amount_type", amountType);
        queryWrapper.orderByDesc("create_date");

        IPage<TaShopAccountLog> result = iTaShopAccountLogService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }
}
