package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.entity.TaExtendContent;
import com.yunzhi.shigongli.entity.TaShopPackageSetting;
import com.yunzhi.shigongli.vo.ShopPackageRecommend;
import com.yunzhi.shigongli.vo.ShopPackageVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITaShopPackageService;
import com.yunzhi.shigongli.entity.TaShopPackage;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
    * 商铺套餐 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "商铺套餐")
@RestController
@RequestMapping("/")
public class TaShopPackageController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopPackageController.class);

    @Autowired
    public ITaShopPackageService iTaShopPackageService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShopPackage",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopPackageList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                          @ApiParam("商铺") @RequestParam(value ="shopId") String shopId) throws Exception{

        IPage<TaShopPackage> pg = new Page<>(pageNum, pageSize);
        IPage<ShopPackageVO> result = iTaShopPackageService.getProfilePage(pg, shopId);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param shopPackageVO 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShopPackage",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taShopPackageAdd(@ApiParam("保存内容") @RequestBody ShopPackageVO shopPackageVO) throws Exception {

        if (iTaShopPackageService.saveProfile(shopPackageVO)){
            return ResponseBean.success(shopPackageVO);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShopPackage/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taShopPackageDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaShopPackageService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param shopPackageVO 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShopPackage/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taShopPackageUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody ShopPackageVO shopPackageVO) throws Exception{

        if (iTaShopPackageService.updateProfile(shopPackageVO)){
            return ResponseBean.success(iTaShopPackageService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShopPackage/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopPackageGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{

        ShopPackageVO shopPackageVO = iTaShopPackageService.getProfileById(id);

        return ResponseBean.success(shopPackageVO);
    }


    /**
     * 商铺套餐列表
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/shop/{shopId}/package",method= RequestMethod.GET)
    @ApiOperation(value="商铺套餐列表", notes = "商铺套餐列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxPackageList(@ApiParam("商铺") @PathVariable String shopId,
                                         @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "5") Integer pageSize) throws Exception{
        IPage<TaShopPackage> page = new Page<>(pageNum, pageSize);

        IPage<TaShopPackage> packageList = iTaShopPackageService.getWxPackageList(page, shopId, getCurrentPerson());

        return ResponseBean.success(packageList);
    }


    /**
     * 商铺套餐列表
     */
    @RequestMapping(value="/wx/package/recommend",method= RequestMethod.GET)
    @ApiOperation(value="推荐套餐列表", notes = "推荐套餐列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxRecommendList(@ApiParam("当前定位") @RequestParam(value ="location") String location) throws Exception{
        List<ShopPackageRecommend> packageList = iTaShopPackageService.getWxRecommendList(location, getCurrentPerson());

        return ResponseBean.success(packageList);
    }

    /**
     * 商铺套餐详情
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/package/{id}",method= RequestMethod.GET)
    @ApiOperation(value="商铺套餐详情", notes = "商铺套餐详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxPackageDetail(@ApiParam("当前套餐ID") @PathVariable String id) throws Exception{
        TaShopPackage shopPackage = iTaShopPackageService.getById(id);

        return ResponseBean.success(shopPackage);
    }

}
