package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaHotelWorker;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaPersonRole;
import com.yunzhi.shigongli.entity.TaShopWorker;
import com.yunzhi.shigongli.service.ITaPersonRoleService;
import com.yunzhi.shigongli.service.ITaShopWorkerService;
import com.yunzhi.shigongli.vo.ShopWorkerListVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
    * 民宿员工 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "商铺员工")
@RestController
@RequestMapping("/")
public class TaShopWorkerController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShopWorkerController.class);

    @Autowired
    public ITaShopWorkerService iTaShopWorkerService;

    @Autowired
    public ITaPersonRoleService iTaPersonRoleService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShopWorker",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopWorkerList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @ApiParam("商铺ID") @RequestParam(value ="shopId", required = false) String shopId) throws Exception{

        IPage<ShopWorkerListVO> pg = new Page<>(pageNum, pageSize);

        IPage<ShopWorkerListVO> result = iTaShopWorkerService.getPagedListBy(pg, shopId);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taShopWorker 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShopWorker",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taShopWorkerAdd(@ApiParam("保存内容") @RequestBody TaShopWorker taShopWorker) throws Exception{


        if (StringUtils.isEmpty(taShopWorker.getPhone())) {
            return ResponseBean.error("请填写联系电话", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (StringUtils.isEmpty(taShopWorker.getShopId())) {
            return ResponseBean.error("请设置商铺信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 如果当前手机号码有已绑定的数据, 那么直接绑定当前人员
        List<TaShopWorker> originList = iTaShopWorkerService.getByPhone(taShopWorker.getPhone());
        if (null != originList && originList.size() > 0) {
            String personId = originList.get(0).getPersonId();
            taShopWorker.setPersonId(personId);
        }

        if (iTaShopWorkerService.save(taShopWorker)){
            return ResponseBean.success(taShopWorker);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShopWorker/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taShopWorkerDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaShopWorkerService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taShopWorker 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShopWorker/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taShopWorkerUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaShopWorker taShopWorker) throws Exception{

        if (StringUtils.isEmpty(taShopWorker.getPhone())) {
            return ResponseBean.error("请填写联系电话", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (StringUtils.isEmpty(taShopWorker.getShopId())) {
            return ResponseBean.error("请设置民宿信息", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (StringUtils.isEmpty(taShopWorker.getPersonId())) {
            // 如果当前手机号码有已绑定的数据, 那么直接绑定当前人员
            List<TaShopWorker> originList = iTaShopWorkerService.getByPhone(taShopWorker.getPhone());
            if (null != originList && originList.size() > 0) {
                String personId = originList.get(0).getPersonId();
                taShopWorker.setPersonId(personId);
            }
        }

        if (iTaShopWorkerService.updateById(taShopWorker)){
            return ResponseBean.success(iTaShopWorkerService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taShopWorker/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taShopWorkerGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaShopWorkerService.getById(id));
    }

    @RequestMapping(value = "/wx/shop/manager/index", method= RequestMethod.GET)
    @ApiOperation(value = "微信商铺端详情", notes = "微信商铺端详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxShopManager() throws Exception {
        TaPerson taPerson = getCurrentPerson();

        // 校验是否店主
        TaPersonRole taPersonRole = iTaPersonRoleService.getPersonRole(taPerson, Constants.TARGET_SHOP);
        if (null == taPersonRole) {
            return ResponseBean.error("当前人员非店主", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return ResponseBean.success(null);

    }

}
