package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.entity.TaLike;
import com.yunzhi.shigongli.entity.TaResource;
import com.yunzhi.shigongli.entity.TaSave;
import com.yunzhi.shigongli.service.*;
import com.yunzhi.shigongli.vo.ResourceFieldVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.entity.TaTourist;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 旅游景点 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "旅游景点")
@RestController
@RequestMapping("/")
public class TaTouristController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaTouristController.class);

    @Autowired
    public ITaTouristService iTaTouristService;

    @Autowired
    public ITaResourceService taResourceService;

    @Autowired
    public ITaImageService iTaImageService;

    @Autowired
    public ITaTargetTypeService taTargetTypeService;

    @Autowired
    public ITaSaveService iTaSaveService;

    @Autowired
    public ITaLikeService iTaLikeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taTourist",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taTouristList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                      @ApiParam("景点名称") @RequestParam(value ="touristName", required = false) String touristName,
                                      @ApiParam("区位") @RequestParam(value ="areaId", required = false) String areaId) throws Exception{

        IPage<TaTourist> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaTourist> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("weight");
        queryWrapper.orderByDesc("create_date");

        IPage<TaTourist> result = iTaTouristService.getPagedBy(pg, touristName, areaId);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taTourist 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taTourist",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taTouristAdd(@ApiParam("保存内容") @RequestBody TaTourist taTourist) throws Exception{

        if (iTaTouristService.createNew(taTourist)){
            return ResponseBean.success(taTourist);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taTourist/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taTouristDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        if(iTaTouristService.removeLogicById(id)){
            taResourceService.removeBy(Constants.TARGET_TOURIST, id);
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taTourist 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taTourist/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taTouristUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaTourist taTourist) throws Exception{

        if (iTaTouristService.updateById(taTourist)){
            iTaImageService.updateImages(Constants.TARGET_TOURIST, taTourist.getTouristId(), taTourist.getImageList());
            taTargetTypeService.updateTypes(Constants.TARGET_TOURIST, taTourist.getTouristId(), taTourist.getTypeList());

            ResourceFieldVO resourceVO = iTaTouristService.copyProperties(taTourist);
            TaResource taResource = taResourceService.getByTarget(Constants.TARGET_TOURIST, id);
            BeanUtils.copyProperties(resourceVO, taResource);
            taResourceService.updateById(taResource);

            return ResponseBean.success(iTaTouristService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taTourist/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taTouristGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaTourist taTourist = iTaTouristService.getById(id);
        if (Constants.STATUS_DELETED.equals(taTourist.getStatus())) {
            return ResponseBean.error("景点不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaResource taResource = taResourceService.getByTarget(Constants.TARGET_TOURIST, id);
        taTourist.setPvNum(taResource.getPvNum());
        taTourist.setUvNum(taResource.getUvNum());
        taTourist.setLikeNum(taResource.getLikeNum());
        taTourist.setImageList(iTaImageService.getListBy(Constants.TARGET_TOURIST, id));
        taTourist.setTypeList(taTargetTypeService.getListBy(Constants.TARGET_TOURIST, id));

        try {
            taResourceService.recordPerson(Constants.TARGET_TOURIST, id, getCurrentPerson());
        } catch (Exception e) {
            e.printStackTrace();
        }

        return ResponseBean.success(taTourist);
    }


    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/tourist/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getWxDetail(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaTourist taTourist = iTaTouristService.getById(id);
        if (Constants.STATUS_DELETED.equals(taTourist.getStatus())) {
            return ResponseBean.error("景点不存在", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaResource taResource = taResourceService.getByTarget(Constants.TARGET_TOURIST, id);
        taTourist.setPvNum(taResource.getPvNum());
        taTourist.setUvNum(taResource.getUvNum());
        taTourist.setLikeNum(taResource.getLikeNum());
        taTourist.setImageList(iTaImageService.getListBy(Constants.TARGET_TOURIST, id));
        taTourist.setTypeList(taTargetTypeService.getListBy(Constants.TARGET_TOURIST, id));

        // 是否收藏
        TaSave taSave = iTaSaveService.getByTarget(Constants.TARGET_TOURIST, id, getCurrentPerson().getPersonId());
        taTourist.setIsSaved(null == taSave ? 0 : 1);

        // 是否点赞
        TaLike taLike = iTaLikeService.getByTarget(Constants.TARGET_TOURIST, id, getCurrentPerson().getPersonId());
        taTourist.setIsLike(null == taLike ? 0 : 1);

        try {
            taResourceService.recordPerson(Constants.TARGET_TOURIST, id, getCurrentPerson());
        } catch (Exception e) {
            e.printStackTrace();
        }

        return ResponseBean.success(taTourist);
    }
}
