package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.*;
import com.yunzhi.shigongli.service.*;
import com.yunzhi.shigongli.vo.VerifyTargetVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 核销内容表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "核销内容表")
@RestController
@RequestMapping("/")
public class TaVerifyTargetController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaVerifyTargetController.class);

    @Autowired
    public ITaVerifyTargetService iTaVerifyTargetService;

    @Autowired
    public ITaOrderSubService iTaOrderSubService;

    @Autowired
    public ITaOrderService iTaOrderService;

    @Autowired
    public ITaShopWorkerService shopWorkerService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/verifyTarget",method= RequestMethod.GET)
    @ApiOperation(value="核销内容表", notes = "核销内容表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdTypeList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @ApiParam("商铺ID") @RequestParam(value ="shopId", required = false) String shopId,
                                   @ApiParam("客户手机") @RequestParam(value ="phone", required = false) String phone,
                                   @ApiParam("是否本人") @RequestParam(value ="isMine", required = false) Boolean isMine,
                                   @ApiParam("是否核销") @RequestParam(value ="isVerified", required = false) Integer isVerified) throws Exception{

        String personId = getCurrentPerson().getPersonId();
        if (!StringUtils.isEmpty(shopId)) {
            // 如果商铺不为空, 那么检索商铺的核销订单
            personId = null;
        }

        if (null != isMine && isMine) {
            personId = getCurrentPerson().getPersonId();
        }

        IPage<VerifyTargetVO> pg = new Page<>(pageNum, pageSize);
        IPage<VerifyTargetVO> result = iTaVerifyTargetService.getWxPagedBy(pg, personId, shopId, phone, isVerified);
        return ResponseBean.success(result);
    }

    /**
     * 核销
     * @param id
     * @return
     * @throws Exception
     */
    @PutMapping("/wx/verifyTarget/{id}")
    @ApiOperation(value="订单项目核销", notes = "订单项目核销", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean valdiation(@ApiParam(value = "核销码") @PathVariable String id) throws Exception {
        TaVerifyTarget taVerifyTarget = iTaVerifyTargetService.getById(id);
        if (null == taVerifyTarget || Constants.STATUS_DELETED.equals(taVerifyTarget.getStatus())) {
            return ResponseBean.error("未找到待核销内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();
        TaOrder taOrder = iTaOrderService.getById(taVerifyTarget.getOrderId());
        TaOrderSub taOrderSub = iTaOrderSubService.getById(taVerifyTarget.getSubOrderId());

        // 是否属于当前用户
        String personId = getCurrentPerson().getPersonId();
        if (!personId.equals(taVerifyTarget.getPersonId())) {
            return ResponseBean.error("您无权核销当前内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        LocalDateTime expireDate = taVerifyTarget.getExpireDate();
        if (null != expireDate && expireDate.isBefore(LocalDateTime.now())) {
            return ResponseBean.error("当前项目已过期", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 核销
        iTaVerifyTargetService.verify(taVerifyTarget);

        // 是否当前子订单下所有都已经核销完成
        int cnt = iTaVerifyTargetService.getCountBy(taVerifyTarget.getOrderId(), taVerifyTarget.getSubOrderId(), 0);
        if (cnt == 0) {
            iTaOrderSubService.validation(taPerson, taOrder, taOrderSub);
        }

        return ResponseBean.success("核销成功");
    }

    /**
     * 核销确认
     * @param id
     * @return
     * @throws Exception
     */
    @PutMapping("/wx/verifyTarget/{id}/confirm")
    @ApiOperation(value="核销确认", notes = "核销确认", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean valdiateConfirm(@ApiParam(value = "核销码") @PathVariable String id) throws Exception {
        TaVerifyTarget taVerifyTarget = iTaVerifyTargetService.getById(id);
        if (null == taVerifyTarget || Constants.STATUS_DELETED.equals(taVerifyTarget.getStatus())) {
            return ResponseBean.error("未找到待核销内容", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null != taVerifyTarget.getIsConfirmVerified() && taVerifyTarget.getIsConfirmVerified()) {
            return ResponseBean.error("请勿重复确认核销", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaPerson taPerson = getCurrentPerson();
        TaOrder taOrder = iTaOrderService.getById(taVerifyTarget.getOrderId());
        TaOrderSub taOrderSub = iTaOrderSubService.getById(taVerifyTarget.getSubOrderId());

        // 是否属于当前用户
        List<TaShopWorker> workerList = shopWorkerService.getByPerson(taPerson.getPersonId());
        if (null == workerList || workerList.size() < 1) {
            return ResponseBean.error("您无权操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        boolean isOwner = false;
        for (TaShopWorker worker : workerList) {
            isOwner = isOwner || worker.getShopId().equals(taOrderSub.getShopId());
        }
        if (!isOwner) {
            return ResponseBean.error("您无权操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 确认核销
        taVerifyTarget.setIsConfirmVerified(true);
        taVerifyTarget.setConfirmPerson(taPerson.getPersonId());
        taVerifyTarget.setConfirmDate(LocalDateTime.now());
        iTaVerifyTargetService.updateById(taVerifyTarget);

        return ResponseBean.success("ok");
    }
}
