package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITdCityService;
import com.yunzhi.shigongli.entity.TdCity;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 城市表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "城市表")
@RestController
@RequestMapping("/")
public class TdCityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdCityController.class);

    @Autowired
    public ITdCityService iTdCityService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/city",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdCityList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @ApiParam("父级分类") @RequestParam(value ="areaPId", required = false) String areaPId,
                                   @ApiParam("名称") @RequestParam(value ="areaName", required = false) String areaName) throws Exception{

        IPage<TdCity> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdCity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isEmpty(areaPId),"area_p_id", areaPId);
        queryWrapper.like(!StringUtils.isEmpty(areaName), "area_name","%"+areaName+"%");
        queryWrapper.orderByAsc("area_id");

        IPage<TdCity> result = iTdCityService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }
//
//    /**
//     * 保存对象
//     * @param tdCity 实体对象
//     * @return
//     */
//    @RequestMapping(value="/tdCity",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean tdCityAdd(@ApiParam("保存内容") @RequestBody TdCity tdCity) throws Exception{
//
//        if (iTdCityService.save(tdCity)){
//            return ResponseBean.success(tdCity);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/tdCity/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean tdCityDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTdCityService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param tdCity 实体对象
//     * @return
//     */
//    @RequestMapping(value="/tdCity/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean tdCityUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TdCity tdCity) throws Exception{
//
//        if (iTdCityService.updateById(tdCity)){
//            return ResponseBean.success(iTdCityService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/city/{id}",method= RequestMethod.GET)
    @ApiOperation(value="获取地域信息", notes = "获取地域信息", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdCityGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TdCity tdCity = iTdCityService.getById(id);
        if (null == tdCity) {
            return ResponseBean.error("未找到指定地区", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TdCity parent = iTdCityService.getById(tdCity.getAreaPId());
        if (null != parent) {
            tdCity.setAreaPName(parent.getAreaName());
        }

        return ResponseBean.success(tdCity);
    }
}
