package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.yunzhi.shigongli.service.ITdDietMarkService;
import com.yunzhi.shigongli.entity.TdDietMark;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 饮食时刻表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "饮食时刻表")
@RestController
@RequestMapping("/")
public class TdDietMarkController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdDietMarkController.class);

    @Autowired
    public ITdDietMarkService iTdDietMarkService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/dietMark",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tdDietMarkList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable(value ="client") String client,
                                       @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TdDietMark> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TdDietMark> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("sort");

        IPage<TdDietMark> result = iTdDietMarkService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }
//
//    /**
//     * 保存对象
//     * @param tdDietMark 实体对象
//     * @return
//     */
//    @RequestMapping(value="/admin/tdDietMark",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean tdDietMarkAdd(@ApiParam("保存内容") @RequestBody TdDietMark tdDietMark) throws Exception{
//
//        if (iTdDietMarkService.save(tdDietMark)){
//            return ResponseBean.success(tdDietMark);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/admin/tdDietMark/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean tdDietMarkDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTdDietMarkService.removeLogicById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param tdDietMark 实体对象
//     * @return
//     */
//    @RequestMapping(value="/admin/tdDietMark/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean tdDietMarkUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TdDietMark tdDietMark) throws Exception{
//
//        if (iTdDietMarkService.updateById(tdDietMark)){
//            return ResponseBean.success(iTdDietMarkService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/tdDietMark/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean tdDietMarkGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTdDietMarkService.getById(id));
//    }
}
