package com.yunzhi.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.shigongli.common.BaseController;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.ResponseBean;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TdType;
import com.yunzhi.shigongli.entity.TrPersonPage;
import com.yunzhi.shigongli.service.ITdTypeService;
import com.yunzhi.shigongli.service.ITrPersonPageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.Duration;
import java.time.LocalDateTime;

/**
 * <p>
    * 用户访问埋点 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */

@Api(tags = "用户访问埋点")
@RestController
@RequestMapping("/")
public class TrPersonPageController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TrPersonPageController.class);

    @Autowired
    public ITrPersonPageService iTrPersonPageService;


    /**
     * 保存对象
     * @param trPersonPage 实体对象
     * @return
     */
    @RequestMapping(value="/wx/track/page",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tdTypeAdd(@ApiParam("保存内容") @RequestBody TrPersonPage trPersonPage) throws Exception{

        LocalDateTime now = LocalDateTime.now();
        trPersonPage.setPersonId(getCurrentPerson().getPersonId());
        trPersonPage.setInDate(now);
        trPersonPage.setOutDate(now);
        trPersonPage.setDwellTime(0l);
        trPersonPage.setCreateDate(now);

        if (iTrPersonPageService.save(trPersonPage)){
            return ResponseBean.success(trPersonPage);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @return
     */
    @RequestMapping(value="/wx/track/page/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tdTypeUpdate(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        TrPersonPage trPersonPage = iTrPersonPageService.getById(id);

        LocalDateTime now = LocalDateTime.now();
        Duration duration = Duration.between(trPersonPage.getInDate(), now);
        trPersonPage.setOutDate(LocalDateTime.now());
        trPersonPage.setDwellTime(duration.toMillis() / 1000);

        if (iTrPersonPageService.updateById(trPersonPage)){
            return ResponseBean.success(trPersonPage);
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

}
