package com.yunzhi.shigongli.controller;

import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import cn.binarywang.wx.miniapp.bean.WxMaPhoneNumberInfo;
import cn.binarywang.wx.miniapp.bean.WxMaUserInfo;
import com.yunzhi.shigongli.common.*;
import com.yunzhi.shigongli.entity.TaMiniappQrcode;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaPersonRole;
import com.yunzhi.shigongli.service.ITaMiniappQrcodeService;
import com.yunzhi.shigongli.service.ITaPersonRecommenderService;
import com.yunzhi.shigongli.service.ITaPersonRoleService;
import com.yunzhi.shigongli.service.ITaPersonService;
import com.yunzhi.shigongli.vo.WxLoginParam;
import com.yunzhi.shigongli.vo.WxMaAuthParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.*;


@Api(tags = "微信小程序")
@RestController
@RequestMapping("/wx")
public class WxMaController extends BaseController {

    @Autowired
    WxUtils wxUtils;

    @Autowired
    ITaPersonService iTaPersonService;

    @Autowired
    ITaMiniappQrcodeService miniappQrcodeService;

    @Autowired
    ITaPersonRecommenderService recommenderService;

    @Autowired
    ITaPersonRoleService personRoleService;

    @GetMapping("/prefetch")
    @ApiOperation(value="微信预拉取数据", notes = "微信预拉取数据", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean perfetch(String appid,
                                 String token,
                                 String code,
                                 Integer timestamp,
                                 String path,
                                 String query,
                                 String scene) throws Exception {
//        WxMaJscode2SessionResult info = wxUtils.getService().getUserService().getSessionInfo(code);
//        String openid = info.getOpenid();
//
//        TaPerson taPerson = iTaPersonService.getByOpenidOrNot(openid);
//
        Map<String, Object> result = new HashMap<>();
//        result.put("personId", taPerson.getPersonId());
//        result.put("openid", taPerson.getOpenid());
//        result.put("sessionKey", info.getSessionKey());

        return ResponseBean.success(result);
    }

    @PostMapping("/login")
    @ApiOperation(value="登录", notes = "登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody WxLoginParam params) throws Exception {
        if (StringUtils.isEmpty(params.getCode())) {
            return ResponseBean.error("登录参数不能为空", ResponseBean.ERROR_MISSING_PARAMS);
        }

        // 返回值
        Map<String, Object> rtn = new HashMap<>();

        boolean isNewPeson = StringUtils.isEmpty(params.getPersonId());

        WxMaJscode2SessionResult info = wxUtils.getService().getUserService().getSessionInfo(params.getCode());
        rtn.put("sessionKey", info.getSessionKey());

        String openid = info.getOpenid();
        TaPerson taPerson = iTaPersonService.getByOpenidOrNot(openid);

        if (null == taPerson || (!isNewPeson && !taPerson.getPersonId().equals(params.getPersonId()))) {
            return ResponseBean.error("初始化信息失败, 请退出重试", ResponseBean.ERROR_UNAVAILABLE);
        }

        rtn.put("person", taPerson);

        // 查询人员角色
        List<TaPersonRole> roleList = personRoleService.getListByPerson(taPerson.getPersonId());
        rtn.put("personRoleList", roleList);

        String fromType = params.getFromType();
        String recommender = params.getRecommender();
        Integer qrCodeId = params.getQrCodeId();
        if (null != qrCodeId && qrCodeId > 0) {
            TaMiniappQrcode miniappQrcode = miniappQrcodeService.getById(qrCodeId);
            if (null != miniappQrcode) {
                String qrcodeParamStr = miniappQrcode.getScene();
                if (!StringUtils.isEmpty(qrcodeParamStr)) {
                    // 把真正的参数返回
                    rtn.put("qrcode", qrcodeParamStr);
                    // 如果小程序码中有
                    Map<String, String> qrcodeParams = StringUtils.parseQueryString(qrcodeParamStr);
                    if (!StringUtils.isEmpty(qrcodeParams.get("id"))) {
                        fromType = qrcodeParams.get("type");
                        recommender = qrcodeParams.get("id");
                    }
                }
            }
        }

        // 如果有推广ID, 比如民宿或者商铺
        if (!StringUtils.isEmpty(recommender)) {
            if (StringUtils.isEmpty(taPerson.getRecommender())) {
                taPerson.setFromType(fromType);
                taPerson.setRecommender(recommender);
                iTaPersonService.updateById(taPerson);
            }

            // 写入推荐表
            try {
                recommenderService.addNewRecommender(taPerson.getPersonId(), fromType, recommender);
            } catch (Exception e) {
                e.printStackTrace();;
            }
        }

        // 生成 token
        Map<String, Object> tokenClaims = new HashMap<>();
        tokenClaims.put("userId", taPerson.getPersonId());
        tokenClaims.put("miniApp", true);
        String authToken = JWTUtils.encode(tokenClaims);
        rtn.put("token", authToken);

        return ResponseBean.success(rtn);
    }

    @PutMapping("/auth-user")
    @ApiOperation(value="授权头像", notes = "授权头像", httpMethod = "PUT", response = TaPerson.class)
    public ResponseBean updateUserInfo(@ApiParam("授权头像的参数") @RequestBody WxMaAuthParam params) throws Exception {
        checkAuthParams(params);

        // 解密用户信息
        WxMaUserInfo userInfo = wxUtils.getService().getUserService().getUserInfo(params.getSessionKey(), params.getEncryptedData(), params.getIv());

        TaPerson taPerson = getCurrentPerson();
        if (null == taPerson) {
            throw new Exception("校验当前人员失败, 请重试");
        }

        taPerson.setAvatar(userInfo.getAvatarUrl());
        taPerson.setNickName(userInfo.getNickName());
        taPerson.setSex(Integer.parseInt(userInfo.getGender()));

        iTaPersonService.updateById(taPerson);

        return ResponseBean.success(taPerson);
    }

    @ApiOperation(value="授权手机", notes = "授权手机", httpMethod = "PUT", response = TaPerson.class)
    @PutMapping("/auth-phone")
    public ResponseBean updateUserPhone(@ApiParam("授权手机的参数") @RequestBody WxMaAuthParam params) throws Exception {
        // 解密
        WxMaPhoneNumberInfo phoneNoInfo = wxUtils.getService().getUserService().getPhoneNoInfo(params.getSessionKey(), params.getEncryptedData(), params.getIv());

        TaPerson taPerson = getCurrentPerson();
        if (null == taPerson) {
            throw new Exception("校验当前人员失败, 请重试");
        }

        taPerson.setPhone(phoneNoInfo.getPhoneNumber());
        iTaPersonService.updateById(taPerson);

        return ResponseBean.success(taPerson);
    }


    @ApiOperation(value="获取二维码内容", notes = "获取二维码内容", httpMethod = "GET", response = TaMiniappQrcode.class)
    @GetMapping("/qrcode/{id}")
    public ResponseBean updateUserPhone(@ApiParam("二维码ID") @PathVariable Integer id) throws Exception {
        // 解密
        TaMiniappQrcode miniappQrcode = miniappQrcodeService.getById(id);
        if (null == miniappQrcode) {
            return ResponseBean.error("未找到对应的二维码参数", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return ResponseBean.success(miniappQrcode);
    }


    private void checkAuthParams(WxMaAuthParam params) throws Exception {
        String signature = params.getSignature();
        String rawData = params.getRawData();
        String encryptedData = params.getEncryptedData();
        String iv = params.getIv();
        String sessionKey = params.getSessionKey();

        if (StringUtils.isEmpty(signature) || StringUtils.isEmpty(rawData) || StringUtils.isEmpty(encryptedData) || StringUtils.isEmpty(iv) || StringUtils.isEmpty(sessionKey)) {
            throw new Exception("缺失授权参数");
        }

        boolean isValid = wxUtils.getService().getUserService().checkUserInfo(sessionKey, rawData, signature);
        if (!isValid) {
            throw new Exception("校验授权参数失败, 请重试");
        }

        return;
    }
}
