package com.yunzhi.shigongli.service.impl;

import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.TaEvaluation;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaShop;
import com.yunzhi.shigongli.mapper.TaEvaluationMapper;
import com.yunzhi.shigongli.mapper.TaShopMapper;
import com.yunzhi.shigongli.service.ITaEvaluationService;

import com.yunzhi.shigongli.vo.EvaluateTarget;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 评价表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaEvaluationServiceImpl extends BaseServiceImpl<TaEvaluationMapper, TaEvaluation> implements ITaEvaluationService {

    @Autowired
    TaShopMapper taShopMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void evaluateSomething(TaPerson taPerson, EvaluateTarget evaluateTarget) throws Exception {
        if (null == evaluateTarget.getEnvironmentScore()
                && null == evaluateTarget.getSweetScore()
                && null == evaluateTarget.getServiceScore()) {
            throw new Exception("未找到评价内容");
        }

        if (evaluateTarget.getEnvironmentScore() < 1
                && evaluateTarget.getSweetScore() < 1
                && evaluateTarget.getServiceScore() < 1) {
            throw new Exception("未找到评价内容");
        }

        // 环境评分
        if (evaluateTarget.getEnvironmentScore() > 0) {
            TaEvaluation taEvaluation = new TaEvaluation();
            taEvaluation.setEvaluateType(Constants.EVALUATE_ENVIRONMENT);
            taEvaluation.setTargetType(evaluateTarget.getTargetType());
            taEvaluation.setTargetId(evaluateTarget.getTargetId());
            taEvaluation.setScore(evaluateTarget.getEnvironmentScore());
            taEvaluation.setPersonId(taPerson.getPersonId());
            taEvaluation.setCreateDate(LocalDateTime.now());
            baseMapper.insert(taEvaluation);

            // 暂时不将用户评分纳入系统
//            if (Constants.TARGET_SHOP.equals(evaluateTarget.getTargetType())) {
//                //
//                taShopMapper.updateScore("environment_score",
//                        taEvaluation.getEvaluateType(),
//                        taEvaluation.getTargetType(),
//                        taEvaluation.getTargetId());
//            }
        }

        // 口味评分
        if (evaluateTarget.getSweetScore() > 0) {
            TaEvaluation taEvaluation = new TaEvaluation();
            taEvaluation.setEvaluateType(Constants.EVALUATE_SWEET);
            taEvaluation.setTargetType(evaluateTarget.getTargetType());
            taEvaluation.setTargetId(evaluateTarget.getTargetId());
            taEvaluation.setScore(evaluateTarget.getSweetScore());
            taEvaluation.setPersonId(taPerson.getPersonId());
            taEvaluation.setCreateDate(LocalDateTime.now());
            baseMapper.insert(taEvaluation);

            // 暂时不将用户评分纳入系统
//            if (Constants.TARGET_SHOP.equals(evaluateTarget.getTargetType())) {
//                //
//                taShopMapper.updateScore("sweet_score",
//                        taEvaluation.getEvaluateType(),
//                        taEvaluation.getTargetType(),
//                        taEvaluation.getTargetId());
//            }
        }

        // 服务评分
        if (evaluateTarget.getServiceScore() > 0) {
            TaEvaluation taEvaluation = new TaEvaluation();
            taEvaluation.setEvaluateType(Constants.EVALUATE_SERVICE);
            taEvaluation.setTargetType(evaluateTarget.getTargetType());
            taEvaluation.setTargetId(evaluateTarget.getTargetId());
            taEvaluation.setScore(evaluateTarget.getServiceScore());
            taEvaluation.setPersonId(taPerson.getPersonId());
            taEvaluation.setCreateDate(LocalDateTime.now());
            baseMapper.insert(taEvaluation);

            // 暂时不将用户评分纳入系统
//            if (Constants.TARGET_SHOP.equals(evaluateTarget.getTargetType())) {
//                //
//                taShopMapper.updateScore("service_score",
//                        taEvaluation.getEvaluateType(),
//                        taEvaluation.getTargetType(),
//                        taEvaluation.getTargetId());
//            }
        }

    }


}
