package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaImage;
import com.yunzhi.shigongli.mapper.TaImageMapper;
import com.yunzhi.shigongli.service.ITaImageService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 商铺图片 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaImageServiceImpl extends BaseServiceImpl<TaImageMapper, TaImage> implements ITaImageService {

    @Autowired
    TaImageMapper taShopImagesMapper;


    @Override
    public void updateImages(String targetType, String targetId, List<TaImage> imageList) throws Exception {
        if (null == imageList) {
            throw new Exception("未找到图片列表信息");
        }

        if (StringUtils.isEmpty(targetType) || StringUtils.isEmpty(targetId)) {
            throw new Exception("未找到有效的属主信息");
        }

        // 先删除所有的
        removeByTarget(targetType, targetId);

        // 再插入新记录
        for (TaImage image: imageList) {
            image.setImageId(null);
            image.setTargetId(targetId);
            image.setTargetType(targetType);
        }

        saveBatch(imageList);
    }

    @Override
    public List<TaImage> getListBy(String targetType, String targetId) {
        LambdaQueryWrapper<TaImage> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaImage::getTargetType, targetType);
        queryWrapper.eq(TaImage::getTargetId, targetId);

        return list(queryWrapper);
    }

    private boolean removeByTarget(String targetType, String targetId) throws Exception {
        LambdaQueryWrapper<TaImage> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaImage::getTargetType, targetType);
        queryWrapper.eq(TaImage::getTargetId, targetId);

        return remove(queryWrapper);
    }
}
