package com.yunzhi.shigongli.service.impl;

import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.*;
import com.yunzhi.shigongli.mapper.TaOrderMapper;
import com.yunzhi.shigongli.mapper.TaOrderSubMapper;
import com.yunzhi.shigongli.mapper.TaPersonAccountLogMapper;
import com.yunzhi.shigongli.mapper.TaPersonAccountMapper;
import com.yunzhi.shigongli.service.ITaPersonAccountService;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 小程序人员账户 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Slf4j
@Service
public class TaPersonAccountServiceImpl extends BaseServiceImpl<TaPersonAccountMapper, TaPersonAccount> implements ITaPersonAccountService {

    @Autowired
    TaOrderMapper taOrderMapper;

    @Autowired
    TaOrderSubMapper orderSubMapper;

    @Autowired
    TaPersonAccountMapper personAccountMapper;

    @Autowired
    TaPersonAccountMapper accountMapper;

    @Autowired
    TaPersonAccountLogMapper accountLogMapper;

    @Async
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void cashback(TaOrderPay taOrderPay) throws Exception {
        String orderId = taOrderPay.getOrderId();
        String orderSubId = taOrderPay.getSubOrderId();
        TaOrder taOrder = taOrderMapper.selectById(orderId);
        Integer cashback = 0;
        boolean isOrderSub = !StringUtils.isEmpty(orderSubId);
        if (isOrderSub) {
            TaOrderSub taOrderSub = orderSubMapper.selectById(orderSubId);
            cashback = taOrderSub.getCashback();
        } else {
            List<TaOrderSub> orderSubList = orderSubMapper.getListByOrder(taOrder.getOrderId());
            cashback = orderSubList.stream().mapToInt(TaOrderSub::getCashback).reduce(Integer::sum).getAsInt();
        }

        TaPersonAccount personAccount = personAccountMapper.getByPerson(taOrder.getPersonId());
        accountMapper.updateCashBack(personAccount.getAccountId(), cashback);

        TaPersonAccountLog accountLog = new TaPersonAccountLog();
        accountLog.setAccountId(personAccount.getAccountId());
        accountLog.setPersonId(taOrder.getPersonId());
        accountLog.setAmountType(Constants.ACCOUNT_CASHBACK);
        accountLog.setAmount(cashback);
        accountLog.setSignType(Constants.ACCOUNT_INCOME);
        accountLog.setTargetType(isOrderSub ? Constants.TARGET_ORDER_SUB : Constants.TARGET_ORDER);
        accountLog.setTargetId(isOrderSub ? orderSubId : orderId);
        accountLog.setOrderId(orderId);
        accountLogMapper.insert(accountLog);
    }

}
