package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.*;
import com.yunzhi.shigongli.mapper.*;
import com.yunzhi.shigongli.service.ITaResourceService;
import com.yunzhi.shigongli.vo.ResourceListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 访问人 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaResourceServiceImpl extends BaseServiceImpl<TaResourceMapper, TaResource> implements ITaResourceService {

    @Autowired
    TaPvMapper taPvMapper;

    @Autowired
    TaUvMapper taUvMapper;

    @Autowired
    TaSearchMapper taSearchMapper;

    @Autowired
    TaHotWordMapper taHotWordMapper;

    @Override
    public TaResource getByTarget(String targetType, String targetId) {
        LambdaQueryWrapper<TaResource> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaResource::getTargetType, targetType);
        queryWrapper.eq(TaResource::getTargetId, targetId);

        return getOne(queryWrapper);
    }

    @Async
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void recordPerson(String targetType, String targetId, TaPerson taPerson) throws Exception {
        LocalDateTime now = LocalDateTime.now();
        String personId = taPerson.getPersonId();

        // pv
        TaPv taPv = new TaPv();
        taPv.setTargetType(targetType);
        taPv.setTargetId(targetId);
        taPv.setPersonId(personId);
        taPv.setCreateDate(now);
        taPvMapper.insert(taPv);
        baseMapper.increaseQuota("pv_num", targetType, targetId);

        // uv
        TaUv taUv = taUvMapper.getByTargetAndPerson(targetType, targetId, personId);
        if (null == taUv) {
            taUv = new TaUv();
            taUv.setTargetType(targetType);
            taUv.setTargetId(targetId);
            taUv.setPersonId(personId);
            taUv.setCreateDate(now);
            taUvMapper.insert(taUv);
            baseMapper.increaseQuota("uv_num", targetType, targetId);
        }
    }

    @Override
    public void removeBy(String targetType, String targetId) {
        LambdaQueryWrapper<TaResource> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaResource::getTargetType, targetType);
        queryWrapper.eq(TaResource::getTargetId, targetId);

        remove(queryWrapper);
    }

    @Override
    public void updateSave(TaSave taSave, int num) {
        if (null == taSave) return;

        TaResource taResource = getByTarget(taSave.getTargetType(), taSave.getTargetId());
        if (null == taResource) {
            return;
        }

        baseMapper.updateQuota("save_num", taSave.getTargetType(), taSave.getTargetId(), num);
    }

    @Override
    public IPage<ResourceListVO> getWxPagedBy(IPage<ResourceListVO> pg, TaPerson taPerson, String location, String typeId) {
        if (StringUtils.isEmpty(location)) {
            // 南京新街口
            location = "116.367742,39.940667";
        }

        return baseMapper.getWxPagedBy(pg, taPerson.getPersonId(), location, typeId);
    }

    @Override
    public void updateLike(TaLike taLike, int num) {
        if (null == taLike) return;

        TaResource taResource = getByTarget(taLike.getTargetType(), taLike.getTargetId());
        if (null == taResource) {
            return;
        }

        baseMapper.updateQuota("like_num", taLike.getTargetType(), taLike.getTargetId(), num);
    }

    @Override
    public IPage<ResourceListVO> searchList(IPage<ResourceListVO> pg, TaPerson currentPerson, String location, String q, String targetType) {
        String word = q.trim();
        String personId = currentPerson.getPersonId();

        // 写入搜索的 log
        try {
            TaSearch searchLog = createSearchLog(word, personId);
            taSearchMapper.insert(searchLog);

            // 更新热搜词次数
            taHotWordMapper.updateSearchNum(word);
        } catch (Exception e) {
            e.printStackTrace();
        }

        return baseMapper.getSearchList(pg, personId, location, word, targetType);
    }

    private TaSearch createSearchLog(String word, String personId) {
        TaSearch taSearch = new TaSearch();
        taSearch.setPersonId(personId);
        taSearch.setKeyword(word);
        taSearch.setCreateDate(LocalDateTime.now());
        return taSearch;
    }
}
