package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.TaShopAccount;
import com.yunzhi.shigongli.entity.TaShopAccountLog;
import com.yunzhi.shigongli.mapper.TaShopAccountLogMapper;
import com.yunzhi.shigongli.mapper.TaShopAccountMapper;
import com.yunzhi.shigongli.service.ITaShopAccountService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 民宿账户 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaShopAccountServiceImpl extends BaseServiceImpl<TaShopAccountMapper, TaShopAccount> implements ITaShopAccountService {

    @Autowired
    TaShopAccountMapper shopAccountMapper;

    @Autowired
    TaShopAccountLogMapper shopAccountLogMapper;

    @Override
    public TaShopAccount getByShop(String shopId) {
        LambdaQueryWrapper<TaShopAccount> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaShopAccount::getShopId, shopId);

        return getOne(queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean commissionSettlement(TaShopAccount taShopAccount, Integer charges) throws Exception {
        int cnt = shopAccountMapper.commissionSettlement(taShopAccount.getAccountId(), charges);
        if (cnt < 1) {
            throw new Exception("待结算佣金不足");
        }

        TaShopAccountLog accountLog = new TaShopAccountLog();
        accountLog.setAccountId(taShopAccount.getAccountId());
        accountLog.setShopId(taShopAccount.getShopId());
        accountLog.setSignType(Constants.ACCOUNT_EXPENSE);
        accountLog.setAmountType(Constants.ACCOUNT_SETTLEMENT);
        accountLog.setAmount(-charges);
        accountLog.setCreateDate(LocalDateTime.now());

        shopAccountLogMapper.insert(accountLog);

        return true;
    }

    @Override
    public TaShopAccount getAccountInfoBy(String shopId) {
        return null;
    }
}
