package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.entity.TaPerson;
import com.yunzhi.shigongli.entity.TaShopPackage;
import com.yunzhi.shigongli.entity.TaShopPackageSetting;
import com.yunzhi.shigongli.entity.TaTargetDietMark;
import com.yunzhi.shigongli.mapper.TaTargetDietMarkMapper;
import com.yunzhi.shigongli.mapper.TaShopPackageMapper;
import com.yunzhi.shigongli.mapper.TaShopPackageSettingMapper;
import com.yunzhi.shigongli.service.ITaShopPackageService;

import com.yunzhi.shigongli.vo.ShopPackageRecommend;
import com.yunzhi.shigongli.vo.ShopPackageVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 商铺套餐 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaShopPackageServiceImpl extends BaseServiceImpl<TaShopPackageMapper, TaShopPackage> implements ITaShopPackageService {

    @Autowired
    TaShopPackageSettingMapper shopPackageSettingMapper;

    @Autowired
    TaTargetDietMarkMapper dietMarkMapper;

    @Override
    public boolean saveProfile(ShopPackageVO shopPackageVO) throws Exception {
        TaShopPackage taShopPackage = new TaShopPackage();
        TaShopPackageSetting shopPackageSetting = new TaShopPackageSetting();

        BeanUtils.copyProperties(shopPackageVO, taShopPackage);
        BeanUtils.copyProperties(shopPackageVO, shopPackageSetting);

        save(taShopPackage);
        shopPackageVO.setPackageId(taShopPackage.getPackageId());

        shopPackageSetting.setPackageId(taShopPackage.getPackageId());

        // 现金券不参与攻略
        if (Constants.PACKAGE_CASH.equals(taShopPackage.getPackageCategory())) {
            shopPackageSetting.setIsStrategy(false);
        } else {
            shopPackageSetting.setIsStrategy(true);
        }

        shopPackageSettingMapper.insert(shopPackageSetting);

        List<TaTargetDietMark> dietMarkList = shopPackageVO.getDietMarkList();
        if (null != dietMarkList) {
            for (TaTargetDietMark dietMark : dietMarkList) {
                dietMark.setTargetId(taShopPackage.getPackageId());
                dietMark.setTargetType(Constants.TARGET_SHOP_PACKAGE);

                dietMarkMapper.insert(dietMark);
            }
            shopPackageVO.setDietMarkList(dietMarkList);
        }

        return true;
    }

    @Override
    public boolean updateProfile(ShopPackageVO shopPackageVO) throws Exception {
        TaShopPackage taShopPackage = new TaShopPackage();
        TaShopPackageSetting shopPackageSetting = new TaShopPackageSetting();

        BeanUtils.copyProperties(shopPackageVO, taShopPackage);
        BeanUtils.copyProperties(shopPackageVO, shopPackageSetting);

        updateById(taShopPackage);
        shopPackageVO.setPackageId(taShopPackage.getPackageId());

        shopPackageSetting.setPackageId(taShopPackage.getPackageId());

        // 现金券不参与攻略
        if (Constants.PACKAGE_CASH.equals(taShopPackage.getPackageCategory())) {
            shopPackageSetting.setIsStrategy(false);
        } else {
            shopPackageSetting.setIsStrategy(true);
        }
        shopPackageSettingMapper.updateById(shopPackageSetting);

        // 先删除
        Map<String, Object> columnMap = new HashMap<>();
        columnMap.put("target_type", Constants.TARGET_SHOP_PACKAGE);
        columnMap.put("target_id", taShopPackage.getPackageId());
        dietMarkMapper.deleteByMap(columnMap);

        // 再插入
        List<TaTargetDietMark> dietMarkList = shopPackageVO.getDietMarkList();
        if (null != dietMarkList) {
            for (TaTargetDietMark dietMark : dietMarkList) {
                dietMark.setTargetId(taShopPackage.getPackageId());
                dietMark.setTargetType(Constants.TARGET_SHOP_PACKAGE);

                dietMarkMapper.insert(dietMark);
            }
            shopPackageVO.setDietMarkList(dietMarkList);
        }

        return true;
    }

    @Override
    public ShopPackageVO getProfileById(String id) {
        ShopPackageVO shopPackageVO = new ShopPackageVO();

        // 先查询基本信息
        TaShopPackage taShopPackage = getById(id);
        BeanUtils.copyProperties(taShopPackage, shopPackageVO);

        // 再查配置信息
        LambdaQueryWrapper<TaShopPackageSetting> query1 = new LambdaQueryWrapper<>();
        query1.eq(TaShopPackageSetting::getPackageId, id);
        TaShopPackageSetting shopPackageSetting = shopPackageSettingMapper.selectOne(query1);
        if (null != shopPackageSetting) {
            BeanUtils.copyProperties(shopPackageSetting, shopPackageVO);
        }

        //
        List<TaTargetDietMark> dietMarkList = dietMarkMapper.getListBy(Constants.TARGET_SHOP_PACKAGE, id);
        shopPackageVO.setDietMarkList(dietMarkList);

        return shopPackageVO;
    }

    @Override
    public IPage<ShopPackageVO> getProfilePage(IPage<TaShopPackage> pg, String shopId) {
        return baseMapper.getProfilePage(pg, shopId);
    }

    @Override
    public IPage<TaShopPackage> getWxPackageList(IPage<TaShopPackage> pg, String shopId, TaPerson currentPerson) {
        return baseMapper.getWxPackageList(pg, Constants.TARGET_SHOP_PACKAGE, shopId, currentPerson.getPersonId());
    }

    @Override
    public List<ShopPackageRecommend> getWxRecommendList(String location, TaPerson taPerson) {
        // 默认获取 3 个
        Integer limit = 3;
        return baseMapper.getWxRecommendList(Constants.TARGET_SHOP_PACKAGE, location, taPerson.getPersonId(), limit);
    }
}
