package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.api.R;
import com.yunzhi.shigongli.common.Constants;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.*;
import com.yunzhi.shigongli.mapper.*;
import com.yunzhi.shigongli.service.ITaShopService;

import com.yunzhi.shigongli.vo.ResourceFieldVO;
import com.yunzhi.shigongli.vo.ShopListVO;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 商铺 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaShopServiceImpl extends BaseServiceImpl<TaShopMapper, TaShop> implements ITaShopService {

    @Autowired
    TaShopMapper taShopMapper;

    @Autowired
    TaShopAccountMapper taShopAccountMapper;

    @Autowired
    TaImageMapper imagesMapper;

    @Autowired
    TaTargetTypeMapper targetTypeMapper;

    @Autowired
    TaResourceMapper taTargetQuotaMapper;

    @Override
    public IPage<ShopListVO> getPageListBy(IPage<ShopListVO> pg, String shopName, String phone) {
        return taShopMapper.getPageListBy(pg, shopName, phone);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void createNew(TaShop taShop) throws Exception {
        save(taShop);

        TaShopAccount account = new TaShopAccount();
        account.setShopId(taShop.getShopId());

        taShopAccountMapper.insert(account);

        // 指标表
        ResourceFieldVO resourceVO = copyProperties(taShop);

        TaResource taResource = new TaResource();
        BeanUtils.copyProperties(resourceVO, taResource);
        taResource.setTargetType(Constants.TARGET_SHOP);
        taResource.setTargetId(taShop.getShopId());
        taResource.setLikeNum(taShop.getLikeNum());
        taTargetQuotaMapper.insert(taResource);

        // 图片
        if (null != taShop.getImageList()) {
            for (TaImage image: taShop.getImageList()) {
                image.setTargetType(Constants.TARGET_SHOP);
                image.setTargetId(taShop.getShopId());
                imagesMapper.insert(image);
            }
        }

        // 分类标签
        if (null != taShop.getTypeList()) {
            for (TaTargetType type: taShop.getTypeList()) {
                type.setTargetType(Constants.TARGET_SHOP);
                type.setTargetId(taShop.getShopId());
                targetTypeMapper.insert(type);
            }
        }
    }

    @Override
    public boolean updatePVNum(String id) {
        try {
            return taShopMapper.updatePVNum(id) > 0;
        } catch (Exception e) {
            e.printStackTrace();
            return false;
        }
    }

    @Override
    public ResourceFieldVO copyProperties(TaShop taShop) {
        ResourceFieldVO resourceVO = new ResourceFieldVO();
        BeanUtils.copyProperties(taShop, resourceVO);
        if (!StringUtils.isEmpty(taShop.getLocaton())) {
            String[] loc = taShop.getLocaton().split(",");
            resourceVO.setLng(loc[0].trim());
            resourceVO.setLat(loc[1].trim());
        }
        return  resourceVO;
    }

    @Override
    public List<TaShop> getListByPerson(TaPerson taPerson) {
        return taShopMapper.getListByPerson(taPerson.getPersonId());
    }
}
