package com.yunzhi.shigongli.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yunzhi.shigongli.common.StringUtils;
import com.yunzhi.shigongli.entity.TaImage;
import com.yunzhi.shigongli.entity.TaTargetType;
import com.yunzhi.shigongli.mapper.TaTargetTypeMapper;
import com.yunzhi.shigongli.service.ITaTargetTypeService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 资源分类表 服务实现类
 * </p>
 *
 * @author yansen
 * @since 2021-08-17
 */
@Service
public class TaTargetTypeServiceImpl extends BaseServiceImpl<TaTargetTypeMapper, TaTargetType> implements ITaTargetTypeService {

    @Override
    public void updateTypes(String targetType, String targetId, List<TaTargetType> typeList) throws Exception {
        if (null == typeList) {
            throw new Exception("未找到图片列表信息");
        }

        if (StringUtils.isEmpty(targetType) || StringUtils.isEmpty(targetId)) {
            throw new Exception("分类标签对象信息不完整");
        }

        // 先删除所有的
        removeByTarget(targetType, targetId);

        // 再插入新记录
        for (TaTargetType item : typeList) {
            item.setTargetType(targetType);
            item.setTargetId(targetId);
        }

        saveBatch(typeList);
    }

    @Override
    public List<TaTargetType> getListBy(String targetType, String targetId) {
        LambdaQueryWrapper<TaTargetType> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaTargetType::getTargetType, targetType);
        queryWrapper.eq(TaTargetType::getTargetId, targetId);
        return list(queryWrapper);
    }

    private boolean removeByTarget(String targetType, String targetId) throws Exception {
        LambdaQueryWrapper<TaTargetType> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaTargetType::getTargetType, targetType);
        queryWrapper.eq(TaTargetType::getTargetId, targetId);

        return remove(queryWrapper);
    }
}
